<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:xalan="http://xml.apache.org/xslt">

	<xsl:output method="xml" indent="yes" encoding="UTF-8" />

	<!-- External parameter used by the match="/" template -->
	<xsl:param name="PREPROCESS">false</xsl:param>

	<!-- Output file is not a well formed xml file      -->
	<!-- Output format must strictly adhere to standard -->
	<!-- used by CatMgr v.1.1.1                         -->
	<xsl:variable name="NEWLINE">
		<xsl:text>&#10;</xsl:text>
	</xsl:variable>

	<!-- This builds the single vendor row -->
	<xsl:template match="Vendor">
		<xsl:value-of select="@ID" />
		<xsl:text>,"</xsl:text>
		<xsl:value-of select="@Name" disable-output-escaping="yes" />
		<xsl:text>",""</xsl:text>
		<xsl:value-of select="$NEWLINE" />
	</xsl:template>

	<!-- This builds a single Component -->
	<xsl:template match="Release">
		<xsl:if test="../../@Os='Unix' or ../../@Os='Windows'">
			<xsl:element name="Component">
				<xsl:value-of select="$NEWLINE" />
				<xsl:value-of select="substring(@ID, 5)" />
				<xsl:text>,"</xsl:text>
				<xsl:choose>
  				<xsl:when test="@Name">
  			  	<xsl:value-of select="@Name" disable-output-escaping="yes"/>
  				</xsl:when>
  				<xsl:otherwise>
  				 <xsl:choose>
  				  <xsl:when test="../@Name">
  				    <xsl:value-of select="../@Name" disable-output-escaping="yes"/>
  				  </xsl:when>
  				  <xsl:otherwise>
  				    <xsl:value-of select="../../@Name" disable-output-escaping="yes"/>
  				  </xsl:otherwise>
  				 </xsl:choose>
  				</xsl:otherwise>
				</xsl:choose>
				<xsl:text>","</xsl:text>
				<xsl:value-of select="@Version" disable-output-escaping="yes" />
				<xsl:text>","</xsl:text>
				<xsl:value-of select="../../@Os" disable-output-escaping="yes" />
				<xsl:text>",2,"P",1,"</xsl:text>
				<xsl:value-of select="../../@Description" disable-output-escaping="yes" />
				<xsl:text>",</xsl:text>
				<xsl:choose>
  				  <xsl:when test="../../@VendorID">
  				    <xsl:value-of select="../../@VendorID" disable-output-escaping="yes" />
  				  </xsl:when>
  				  <xsl:otherwise>
  				    <xsl:value-of select="1" disable-output-escaping="yes"/>
  				  </xsl:otherwise>
				</xsl:choose>
				<xsl:value-of select="$NEWLINE" />

				<!-- Build a list of ExeFile entries -->
				<xsl:apply-templates select="id(@Modules)"></xsl:apply-templates>
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<!-- This builds a single ExeFile -->
	<xsl:template match="File">
		<!-- Catalog Manager 1.1.1 does not manage Monitoring modules -->
		<xsl:if test="not(@Scope='Monitoring') and (@Os='Unix' or @Os='Windows')">
			<xsl:element name="ExeFile">
				<xsl:text>"</xsl:text>
				<xsl:value-of select="@Name" disable-output-escaping="yes" />
				<xsl:text>",</xsl:text>
				<xsl:value-of select="@Size" disable-output-escaping="yes" />
				<xsl:text>,"","</xsl:text>
				<xsl:value-of select="@SignatureName" disable-output-escaping="yes" />
				<xsl:text>","</xsl:text>
				<xsl:value-of select="@SignatureVersion" disable-output-escaping="yes" />
				<xsl:text>"</xsl:text>
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<!-- This builds the Vendors section -->
	<xsl:template match="Vendors">
		<xsl:element name="Vendors">
			<xsl:value-of select="$NEWLINE" />
			<xsl:apply-templates select="Vendor"></xsl:apply-templates>
		</xsl:element>
	</xsl:template>

	<!-- This builds the Components section -->
	<xsl:template match="Products">
		<xsl:element name="Components">
			<xsl:apply-templates select="Product/Version/Release"></xsl:apply-templates>
		</xsl:element>
	</xsl:template>

	<!-- This builds the root element or just preprocess the doc -->
	<xsl:template match="/">
		<xsl:choose>

			<!-- This only preprocess the TLM 2.1 catalog to add internal DTD -->
			<xsl:when test="$PREPROCESS = 'true'">
				<xsl:text disable-output-escaping="yes">&lt;!DOCTYPE IBMSoftwareCatalog [</xsl:text>
				<xsl:text disable-output-escaping="yes">&lt;!ATTLIST File ID ID #REQUIRED&gt;</xsl:text>
				<xsl:text disable-output-escaping="yes">]&gt;</xsl:text>
				<xsl:copy-of select="/" />
			</xsl:when>

			<!-- This builds the TLM 1.1.1 catalog -->
			<xsl:otherwise>
				<!-- Build root element so that each attribute is on a new line -->
				<xsl:text disable-output-escaping="yes">&lt;IBMSoftwareCatalog</xsl:text>
				<xsl:value-of select="$NEWLINE" />
				<xsl:text>Description="</xsl:text>
				<xsl:value-of select="IBMSoftwareUpdate/@Description" />
				<xsl:text>"</xsl:text>
				<xsl:value-of select="$NEWLINE" />
				<xsl:text>Copyright="</xsl:text>
				<xsl:value-of select="IBMSoftwareUpdate/@Copyright" />
				<xsl:text>"</xsl:text>
				<xsl:value-of select="$NEWLINE" />
				<xsl:text>Version="</xsl:text>
				<xsl:value-of select="IBMSoftwareUpdate/@Version" />
				<xsl:text>"</xsl:text>
				<xsl:value-of select="$NEWLINE" />
				<xsl:text>Timestamp="</xsl:text>
				<xsl:value-of select="IBMSoftwareUpdate/@Date" />
				<xsl:text>"</xsl:text>
				<xsl:text disable-output-escaping="yes">&gt;</xsl:text>
				<xsl:value-of select="$NEWLINE" />
				<xsl:apply-templates select="//Vendors"></xsl:apply-templates>
				<xsl:apply-templates select="//Products"></xsl:apply-templates>
				<xsl:value-of select="$NEWLINE" />
				<xsl:text disable-output-escaping="yes">&lt;/IBMSoftwareCatalog&gt;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
