-- ****************************************************************************
-- * Licensed Materials - Property of IBM
-- * 5724-D33
-- * IBM Tivoli License Manager
-- *
-- * (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
-- *
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ****************************************************************************


-------------------------------------------------------------------------------
-- Logical unique index on enduser.logon_name field
-------------------------------------------------------------------------------

create trigger ADM.ENDUSER_UI_TR1 no cascade
    before insert on ADM.ENDUSER
    referencing new as NEW for each row mode db2sql
    when ( exists ( select LOGON_NAME
                    from ADM.ENDUSER
                    where LOGON_NAME = NEW.LOGON_NAME and
                          CUSTOMER_ID = NEW.CUSTOMER_ID ) )
    signal sqlstate '70001' ('ENDUSER.LOGON_NAME duplicated');

create trigger ADM.ENDUSER_UI_TR2 no cascade
    before update of LOGON_NAME on ADM.ENDUSER
    referencing new as NEW for each row mode db2sql
    when ( exists ( select LOGON_NAME
                    from ADM.ENDUSER
                    where LOGON_NAME = NEW.LOGON_NAME and
                          CUSTOMER_ID = NEW.CUSTOMER_ID and
                          ID <> NEW.ID ) )
    signal sqlstate '70001' ('ENDUSER.LOGON_NAME duplicated');

-------------------------------------------------------------------------------
-- Logical unique index on node.name field
-------------------------------------------------------------------------------

create trigger ADM.NODE_UI_TR1 no cascade
    before insert on ADM.NODE
    referencing new as NEW for each row mode db2sql
    when ( exists ( select NAME
                    from ADM.NODE
                    where NAME = NEW.NAME and
                          CUSTOMER_ID = NEW.CUSTOMER_ID ) )
    signal sqlstate '70001' ('NODE.NAME duplicated');

create trigger ADM.NODE_UI_TR2 no cascade
    before update of NAME on ADM.NODE
    referencing new as NEW for each row mode db2sql
    when ( exists ( select NAME
                    from ADM.NODE
                    where NAME = NEW.NAME and
                          CUSTOMER_ID = NEW.CUSTOMER_ID and
                          ID <> NEW.ID ) )
    signal sqlstate '70001' ('NODE.NAME duplicated');

-------------------------------------------------------------------------------
-- Referential integrity for license targets
-------------------------------------------------------------------------------

create trigger ADM.LIC_TGT_DEL_TR1
    after delete on ADM.DIVISION
    referencing old as OLD for each row mode db2sql
    delete from ADM.LIC_TARGET_REL
    where TARGET_ID = OLD.ID and
          LICENSE_ID in ( select ADM.LICENSE.ID
                          from ADM.LICENSE, ADM.LIC_TARGET_REL
                          where ADM.LIC_TARGET_REL.LICENSE_ID = ADM.LICENSE.ID and
                                ADM.LICENSE.TARGET_TYPE = 2 and
                                ADM.LIC_TARGET_REL.TARGET_ID = OLD.ID );

create trigger ADM.LIC_TGT_DEL_TR2
    after delete on ADM.NODE
    referencing old as OLD for each row mode db2sql
    delete from ADM.LIC_TARGET_REL
    where TARGET_ID = OLD.ID and
          LICENSE_ID in ( select ADM.LICENSE.ID
                          from ADM.LICENSE, ADM.LIC_TARGET_REL
                          where ADM.LIC_TARGET_REL.LICENSE_ID = ADM.LICENSE.ID and
                                ADM.LICENSE.TARGET_TYPE = 3 and
                                ADM.LIC_TARGET_REL.TARGET_ID = OLD.ID );

create trigger ADM.LIC_TGT_DEL_TR3
    after delete on ADM.AGENT
    referencing old as OLD for each row mode db2sql
    delete from ADM.LIC_TARGET_REL
    where TARGET_ID = OLD.ID and
          LICENSE_ID in ( select ADM.LICENSE.ID
                          from ADM.LICENSE, ADM.LIC_TARGET_REL
                          where ADM.LIC_TARGET_REL.LICENSE_ID = ADM.LICENSE.ID and
                                ADM.LICENSE.TARGET_TYPE = 4 and
                                ADM.LIC_TARGET_REL.TARGET_ID = OLD.ID );

-------------------------------------------------------------------------------
-- Clean inventory tables when deleting an agent
-------------------------------------------------------------------------------

create trigger ADM.AGENT_DEL_TR1
    after delete on ADM.AGENT
    referencing old as OLD for each row mode db2sql
    update ADM.AGENT_INV
    set END_TIME = current timestamp - current timezone
    where ADM.AGENT_INV.AGENT_ID = OLD.ID and
          END_TIME = '9999-12-31-00.00.00.000000';

create trigger ADM.AGENT_DEL_TR2
    after delete on ADM.AGENT
    referencing old as OLD for each row mode db2sql
    update ADM.AGENT_INV_LIC
    set END_TIME = current timestamp - current timezone
    where ADM.AGENT_INV_LIC.AGENT_INV_ID in
            ( select ADM.AGENT_INV.ID
              from ADM.AGENT_INV
              where ADM.AGENT_INV.AGENT_ID = OLD.ID ) and
          END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------
-- Unlink procured licenses for disabled products
-------------------------------------------------------------------------------

create trigger ADM.COMPONENT_TR1
    after update on ADM.COMPONENT
    referencing new as NEW for each row mode db2sql
    when ( NEW.LEVEL_ = 10 )
    update ADM.PLICENSE
    set LAST_MODIFIED = current timestamp - current timezone
    where ID in ( select PLICENSE_ID
                  from   ADM.PLIC_COMP_REL
                  where  COMPONENT_ID = NEW.ID );

create trigger ADM.COMPONENT_TR2
    after update on ADM.COMPONENT
    referencing new as NEW for each row mode db2sql
    when ( NEW.LEVEL_ = 10 )
    delete from ADM.PLIC_COMP_REL
    where COMPONENT_ID = NEW.ID;

-------------------------------------------------------------------------------
-- Update distribution for deleted licenses
-------------------------------------------------------------------------------

create trigger ADM.LICENSE_DEL_TR1
    after delete on ADM.LICENSE
    referencing old as OLD for each row mode db2sql
    update ADM.LICENSE_DISTRIBUTION
    set QUANTITY = -1
    where LICENSE_ID = OLD.ID;

-------------------------------------------------------------------------------
-- Update divisions after security_level update on customer
-------------------------------------------------------------------------------

create trigger ADM.CUSTOMER_SL_TR1
    after update on ADM.CUSTOMER
    referencing new as NEW old as OLD for each row mode db2sql
    when ( NEW.SECURITY_LEVEL != OLD.SECURITY_LEVEL )
        update ADM.DIVISION
        set LAST_MODIFIED = current timestamp - current timezone
        where CUSTOMER_ID = OLD.ID;

-------------------------------------------------------------------------------
-- Unique IDs generation for import / export
-------------------------------------------------------------------------------

create trigger ADM.ADMIN_EXT_ID
    no cascade before insert on ADM.ADMINISTRATOR
    referencing new as NEW for each row mode db2sql
    when (NEW.EXT_ID is null)
    set NEW.EXT_ID = rtrim('TLM_' concat
                           (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                           '_' concat
                           char(NEW.ID));

create trigger ADM.CONTRACT_EXT_ID
    no cascade before insert on ADM.CONTRACT
    referencing new as NEW for each row mode db2sql
    when (NEW.EXT_ID is null)
    set NEW.EXT_ID = rtrim('TLM_' concat
                           (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                           '_' concat
                           char(NEW.ID));

create trigger ADM.DIVISION_EXT_ID
    no cascade before insert on ADM.DIVISION
    referencing new as NEW for each row mode db2sql
    when (NEW.EXT_ID is null)
    set NEW.EXT_ID = rtrim('TLM_' concat
                           (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                           '_' concat
                           char(NEW.ID));

create trigger ADM.ENDUSER_EXT_ID
    no cascade before insert on ADM.ENDUSER
    referencing new as NEW for each row mode db2sql
    when (NEW.EXT_ID is null)
    set NEW.EXT_ID = rtrim('TLM_' concat
                           (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                           '_' concat
                           char(NEW.ID));

create trigger ADM.LICENSE_EXT_ID
    no cascade before insert on ADM.LICENSE
    referencing new as NEW for each row mode db2sql
    when (NEW.EXT_ID is null)
    set NEW.EXT_ID = rtrim('TLM_' concat
                           (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                           '_' concat
                           char(NEW.ID));

create trigger ADM.NODE_EXT_ID
    no cascade before insert on ADM.NODE
    referencing new as NEW for each row mode db2sql
    when (NEW.EXT_ID is null)
    set NEW.EXT_ID = rtrim('TLM_' concat
                           (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                           '_' concat
                           char(NEW.ID));

create trigger ADM.PLICENSE_EXT_ID
    no cascade before insert on ADM.PLICENSE
    referencing new as NEW for each row mode db2sql
    when (NEW.EXT_ID is null)
    set NEW.EXT_ID = rtrim('TLM_' concat
                           (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                           '_' concat
                           char(NEW.ID));

-------------------------------------------------------------------------------
-- Historical triggers
-------------------------------------------------------------------------------

create trigger ADM.AGENT_H1
    after insert on ADM.AGENT
    referencing new as NEW for each row mode db2sql
        insert into ADM.AGENT_H
        values (
            NEW.ID,
            NEW.VERSION,
            NEW.OS_VERSION,
            NEW.SERVER_ID,
            NEW.NODE_ID,
            NEW.DIVISION_ID,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'I',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.AGENT_H2
    after update of SERVER_ID, NODE_ID, DIVISION_ID on ADM.AGENT
    referencing new as NEW for each row mode db2sql
        update ADM.AGENT_H
        set END_TIME = NEW.LAST_MODIFIED,
            END_ACTION = 'U'
        where ID = NEW.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

create trigger ADM.AGENT_H3
    after update of SERVER_ID, NODE_ID, DIVISION_ID on ADM.AGENT
    referencing new as NEW for each row mode db2sql
        insert into ADM.AGENT_H
        values (
            NEW.ID,
            NEW.VERSION,
            NEW.OS_VERSION,
            NEW.SERVER_ID,
            NEW.NODE_ID,
            NEW.DIVISION_ID,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'U',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.AGENT_H4
    after delete on ADM.AGENT
    referencing old as OLD for each row mode db2sql
        update ADM.AGENT_H
        set END_TIME = current timestamp - current timezone,
            END_ACTION = 'D'
        where ID = OLD.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------

create trigger ADM.DIVISION_H1
    after insert on ADM.DIVISION
    referencing new as NEW for each row mode db2sql
        insert into ADM.DIVISION_H
        values (
            NEW.ID,
            NEW.NAME,
            NEW.INV_START_DATE,
            NEW.INV_RATE_TYPE,
            NEW.INV_RATE_VALUE,
            NEW.DESCRIPTION,
            NEW.SECURITY_LEVEL,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'I',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.DIVISION_H2
    after update on ADM.DIVISION
    referencing new as NEW for each row mode db2sql
        update ADM.DIVISION_H
        set END_TIME = NEW.LAST_MODIFIED,
            END_ACTION = 'U'
        where ID = NEW.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

create trigger ADM.DIVISION_H3
    after update on ADM.DIVISION
    referencing new as NEW for each row mode db2sql
        insert into ADM.DIVISION_H
        values (
            NEW.ID,
            NEW.NAME,
            NEW.INV_START_DATE,
            NEW.INV_RATE_TYPE,
            NEW.INV_RATE_VALUE,
            NEW.DESCRIPTION,
            NEW.SECURITY_LEVEL,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'U',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.DIVISION_H4
    after delete on ADM.DIVISION
    referencing old as OLD for each row mode db2sql
        update ADM.DIVISION_H
        set END_TIME = current timestamp - current timezone,
            END_ACTION = 'D'
        where ID = OLD.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------

create trigger ADM.LICENSE_H1
    after insert on ADM.LICENSE
    referencing new as NEW for each row mode db2sql
        insert into ADM.LICENSE_H
        values (
            NEW.ID,
            NEW.REF_CODE,
            NEW.QUANTITY,
            NEW.TARGET_TYPE,
            NEW.ALL_TARGETS,
            NEW.ALL_USERS,
            NEW.PLICENSE_ID,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'I',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.LICENSE_H2
    after update on ADM.LICENSE
    referencing new as NEW for each row mode db2sql
        update ADM.LICENSE_H
        set END_TIME = NEW.LAST_MODIFIED,
            END_ACTION = 'U'
        where ID = NEW.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

create trigger ADM.LICENSE_H3
    after update on ADM.LICENSE
    referencing new as NEW for each row mode db2sql
        insert into ADM.LICENSE_H
        values (
            NEW.ID,
            NEW.REF_CODE,
            NEW.QUANTITY,
            NEW.TARGET_TYPE,
            NEW.ALL_TARGETS,
            NEW.ALL_USERS,
            NEW.PLICENSE_ID,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'U',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.LICENSE_H4
    after delete on ADM.LICENSE
    referencing old as OLD for each row mode db2sql
        update ADM.LICENSE_H
        set END_TIME = current timestamp - current timezone,
            END_ACTION = 'D'
        where ID = OLD.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------

create trigger ADM.LIC_USER_HREL1
    after insert on ADM.LIC_USER_REL
    referencing new as NEW for each row mode db2sql
    insert into ADM.LIC_USER_HREL
    values (
        NEW.LICENSE_ID,
        NEW.ENDUSER_ID,
        NEW.LAST_MODIFIED,
        '9999-12-31-00.00.00.000000' );

create trigger ADM.LIC_USER_HREL4
    after delete on ADM.LIC_USER_REL
    referencing old as OLD for each row mode db2sql
        update ADM.LIC_USER_HREL
        set END_TIME = current timestamp - current timezone
        where LICENSE_ID = OLD.LICENSE_ID and
              ENDUSER_ID = OLD.ENDUSER_ID and
              END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------

create trigger ADM.LIC_TARGET_H1
    after insert on ADM.LIC_TARGET_REL
    referencing new as NEW for each row mode db2sql
    insert into ADM.LIC_TARGET_HREL
    values (
        NEW.LICENSE_ID,
        NEW.TARGET_ID,
        NEW.LAST_MODIFIED,
        '9999-12-31-00.00.00.000000' );

create trigger ADM.LIC_TARGET_H4
    after delete on ADM.LIC_TARGET_REL
    referencing old as OLD for each row mode db2sql
        update ADM.LIC_TARGET_HREL
        set END_TIME = current timestamp - current timezone
        where LICENSE_ID = OLD.LICENSE_ID and
              TARGET_ID = OLD.TARGET_ID and
              END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------

create trigger ADM.NODE_H1
    after insert on ADM.NODE
    referencing new as NEW for each row mode db2sql
        insert into ADM.NODE_H
        values (
            NEW.ID,
            NEW.TAG,
            NEW.PLATFORM,
            NEW.NAME,
            NEW.HASH,
            NEW.CAPACITY,
            NEW.OOCOD,
            NEW.PLUGIN_TIME,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'I',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.NODE_H2
    after update on ADM.NODE
    referencing new as NEW for each row mode db2sql
        update ADM.NODE_H
        set END_TIME = NEW.LAST_MODIFIED,
            END_ACTION = 'U'
        where ID = NEW.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

create trigger ADM.NODE_H3
    after update on ADM.NODE
    referencing new as NEW for each row mode db2sql
        insert into ADM.NODE_H
        values (
            NEW.ID,
            NEW.TAG,
            NEW.PLATFORM,
            NEW.NAME,
            NEW.HASH,
            NEW.CAPACITY,
            NEW.OOCOD,
            NEW.PLUGIN_TIME,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'U',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.NODE_H4
    after delete on ADM.NODE
    referencing old as OLD for each row mode db2sql
        update ADM.NODE_H
        set END_TIME = current timestamp - current timezone,
            END_ACTION = 'D'
        where ID = OLD.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------

create trigger ADM.PLICENSE_H1
    after insert on ADM.PLICENSE
    referencing new as NEW for each row mode db2sql
        insert into ADM.PLICENSE_H
        values (
            NEW.ID,
            NEW.REF_CODE,
            NEW.TREE_LEVEL,
            NEW.SOFTWARE_NAME,
            NEW.LICENSE_TYPE,
            NEW.QUANTITY,
            NEW.CAPACITY_TYPE,
            NEW.DELIVERY_DATE,
            NEW.START_DATE,
            NEW.EXPIRATION_DATE,
            NEW.HARD_STOP,
            NEW.MULTI_INSTANCE,
            NEW.THRESHOLD,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'I',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.PLICENSE_H2
    after update on ADM.PLICENSE
    referencing new as NEW for each row mode db2sql
        update ADM.PLICENSE_H
        set END_TIME = NEW.LAST_MODIFIED,
            END_ACTION = 'U'
        where ID = NEW.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

create trigger ADM.PLICENSE_H3
    after update on ADM.PLICENSE
    referencing new as NEW for each row mode db2sql
        insert into ADM.PLICENSE_H
        values (
            NEW.ID,
            NEW.REF_CODE,
            NEW.TREE_LEVEL,
            NEW.SOFTWARE_NAME,
            NEW.LICENSE_TYPE,
            NEW.QUANTITY,
            NEW.CAPACITY_TYPE,
            NEW.DELIVERY_DATE,
            NEW.START_DATE,
            NEW.EXPIRATION_DATE,
            NEW.HARD_STOP,
            NEW.MULTI_INSTANCE,
            NEW.THRESHOLD,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'U',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.PLICENSE_H4
    after delete on ADM.PLICENSE
    referencing old as OLD for each row mode db2sql
        update ADM.PLICENSE_H
        set END_TIME = current timestamp - current timezone,
            END_ACTION = 'D'
        where ID = OLD.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------

create trigger ADM.PLIC_COMP_REL1
    after insert on ADM.PLIC_COMP_REL
    referencing new as NEW for each row mode db2sql
    insert into ADM.PLIC_COMP_HREL
    values (
        NEW.PLICENSE_ID,
        NEW.COMPONENT_ID,
        current timestamp - current timezone,
        '9999-12-31-00.00.00.000000' );

create trigger ADM.PLIC_COMP_REL4
    after delete on ADM.PLIC_COMP_REL
    referencing old as OLD for each row mode db2sql
        update ADM.PLIC_COMP_HREL
        set END_TIME = current timestamp - current timezone
        where PLICENSE_ID = OLD.PLICENSE_ID and
              COMPONENT_ID = OLD.COMPONENT_ID and
              END_TIME = '9999-12-31-00.00.00.000000';

-------------------------------------------------------------------------------

create trigger ADM.SERVER_H1
    after insert on ADM.SERVER
    referencing new as NEW for each row mode db2sql
        insert into ADM.SERVER_H
        values (
            NEW.ID,
            NEW.NAME,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'I',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.SERVER_H2
    after update of NAME on ADM.SERVER
    referencing new as NEW for each row mode db2sql
        update ADM.SERVER_H
        set END_TIME = NEW.LAST_MODIFIED,
            END_ACTION = 'U'
        where ID = NEW.ID and
              END_TIME = '9999-12-31-00.00.00.000000';

create trigger ADM.SERVER_H3
    after update of NAME on ADM.SERVER
    referencing new as NEW for each row mode db2sql
        insert into ADM.SERVER_H
        values (
            NEW.ID,
            NEW.NAME,
            NEW.CUSTOMER_ID,
            NEW.LAST_MODIFIED,
            'U',
            '9999-12-31-00.00.00.000000',
            '' );

create trigger ADM.SERVER_H4
    after delete on ADM.SERVER
    referencing old as OLD for each row mode db2sql
        update ADM.SERVER_H
        set END_TIME = current timestamp - current timezone,
            END_ACTION = 'D'
        where ID = OLD.ID and
              END_TIME = '9999-12-31-00.00.00.000000';
