@REM #########################################################################
@REM # Licensed Materials - Property of IBM
@REM # 5724-D33
@REM # IBM Tivoli License Manager
@REM #
@REM # (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
@REM #
@REM # US Government Users Restricted Rights - Use, duplication or
@REM # disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@REM #########################################################################

@echo off
SET TLM_LOG_FILE=ext_id_update_111.log

:: clean old files and bakup dir
if exist %TLM_LOG_FILE% del %TLM_LOG_FILE%

:: check DB2 command line environment
if not defined DB2CLP goto :db2EnvError

echo _______________________________________________________________________________ >> %TLM_LOG_FILE%
echo Running ext_id migration >> %TLM_LOG_FILE%
echo Current date: %DATE% >> %TLM_LOG_FILE%
echo Current time: %TIME% >> %TLM_LOG_FILE%
echo _______________________________________________________________________________ >> %TLM_LOG_FILE%

::-----------------------------------------------------------------------------
:: Checking for database existence
::-----------------------------------------------------------------------------
echo Checking for database existence >> %TLM_LOG_FILE%
db2 +o -z %TLM_LOG_FILE% connect to tlma
if errorlevel 1 goto :dbNotExisting

::-----------------------------------------------------------------------------
:: Performing preliminary checks on db
::-----------------------------------------------------------------------------
echo Preliminary checks on db running... >> %TLM_LOG_FILE%
db2 -f checks_111_21.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :prChecksFailed
echo Preliminary checks completed successfully >> %TLM_LOG_FILE%

::-----------------------------------------------------------------------------
:: Performing 1.1.1 ext_id update
::-----------------------------------------------------------------------------
echo Ext_id column update running...
db2 +o -z %TLM_LOG_FILE% connect to TLMA
db2 -f ext_id_update_111.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :updExtIdFailed

goto :success

:db2EnvError
echo DB2 environment not initialized >> %TLM_LOG_FILE%
echo Run this command from a DB2 Command Window >> %TLM_LOG_FILE%
echo DB2 environment not initialized
echo Run this command from a DB2 Command Window
goto :eof

:dbNotExisting
echo The administration server db doesn't exist >> %TLM_LOG_FILE%
echo The administration server db doesn't exist
goto :eof

:prChecksFailed
echo Preliminary checks on to be migrated db failed. >> %TLM_LOG_FILE%
echo Check database version is 1.1.1. >> %TLM_LOG_FILE%
echo Cannot start ext_id update procedure. Database version is not the one expected (1.1.1)
goto :disconnectClean

:updExtIdFailed
echo A failure occurred updating ext_id column >> %TLM_LOG_FILE%
goto :failure

::-------------------------------------
:failure
echo Procedure failed - see log (%TLM_LOG_FILE%) for details
goto :disconnectClean

::-----------------------------------------------------------------------------
:: Exit successfully
::-----------------------------------------------------------------------------
:success
echo Administration database 1.1.1 has been successfully updated.
echo _______________________________________________________________________________ >> %TLM_LOG_FILE%
echo Administration database has been successfully updated. >> %TLM_LOG_FILE%
echo Finished at date: %DATE% >> %TLM_LOG_FILE%
echo Finished at time: %TIME% >> %TLM_LOG_FILE%
echo _______________________________________________________________________________ >> %TLM_LOG_FILE%

::-------------------------------------
:disconnectClean
db2 +o disconnect TLMA
