-- ****************************************************************************
-- * Licensed Materials - Property of IBM
-- * 5724-D33
-- * IBM Tivoli License Manager
-- *
-- * (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
-- *
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ****************************************************************************

-------------------------------------------------------------------------------
-- New schema creation
-------------------------------------------------------------------------------
create schema SWCAT;

-- revoke generic grant
revoke all privileges on table SYSIBM.SYSDUMMY1 from tlmsrv;

-------------------------------------------------------------------------------
-- ADM.ADMIN_CUST_REL table dropping and recreating.
-------------------------------------------------------------------------------
create table ADM.ADMIN_CUST_REL1
(
    ADMINISTRATOR_ID    bigint             not null,
    CUSTOMER_ID         bigint             not null,
    PROFILE_ID          bigint             not null,
    HIDE_HOST_INV       smallint           not null  default 1,
    HIDE_HOST           smallint           not null  default 1,
    HIDE_USER           smallint           not null  default 1,
    HIDE_GROUP          smallint           not null  default 1,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

insert into ADM.ADMIN_CUST_REL1 (ADMINISTRATOR_ID,
                                 CUSTOMER_ID,
                                 PROFILE_ID,
                                 LAST_MODIFIED) select ADMINISTRATOR_ID,
                                                       CUSTOMER_ID,
                                                       PROFILE_ID,
                                                       LAST_MODIFIED
                                                  from ADM.ADMIN_CUST_REL;
drop table ADM.ADMIN_CUST_REL;
create table ADM.ADMIN_CUST_REL
(
    ADMINISTRATOR_ID    bigint             not null,
    CUSTOMER_ID         bigint             not null,
    PROFILE_ID          bigint             not null,
    HIDE_HOST_INV       smallint           not null  default 1,
    HIDE_HOST           smallint           not null  default 1,
    HIDE_USER           smallint           not null  default 1,
    HIDE_GROUP          smallint           not null  default 1,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);
insert into ADM.ADMIN_CUST_REL select * from ADM.ADMIN_CUST_REL1;
drop table ADM.ADMIN_CUST_REL1;

alter table ADM.ADMIN_CUST_REL add constraint ADMIN_CUST_PK primary key
(
    ADMINISTRATOR_ID,
    CUSTOMER_ID
);

-------------------------------------------------------------------------------
-- ADM.ADMINISTRATOR table altering..
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.ADMINISTRATOR1
(
    ID                  bigint             not null,
    LOGON_NAME          varchar(180)       not null,
    FIRST_NAME          varchar(120)       not null,
    MIDDLE_NAME         varchar(60),
    LAST_NAME           varchar(120)       not null,
    PASSWORD            varchar(40),
    EMAIL_ADDRESS       varchar(240),
    EVENT_NOTIFICATION  smallint           not null  default 0,
    PHONE               varchar(40),
    FAX                 varchar(40),
    EXT_ID              varchar(80),
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

insert into ADM.ADMINISTRATOR1(ID,
                               LOGON_NAME,
                               FIRST_NAME,
                               MIDDLE_NAME,
                               LAST_NAME,
                               EMAIL_ADDRESS,
                               EVENT_NOTIFICATION,
                               PHONE,
                               FAX,
                               EXT_ID,
                               LAST_MODIFIED) select ID,
                                                     LOGON_NAME,
                                                     FIRST_NAME,
                                                     MIDDLE_NAME,
                                                     LAST_NAME,
                                                     EMAIL_ADDRESS,
                                                     EVENT_NOTIFICATION,
                                                     PHONE,
                                                     FAX,
                                                     rtrim('TLM_' concat
                                                           (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                                                           '_' concat
                                                           char(ID)),
                                                     LAST_MODIFIED
                                          from ADM.ADMINISTRATOR;

--table substitution
drop table ADM.ADMINISTRATOR;
create table ADM.ADMINISTRATOR
(
    ID                  bigint             not null,
    LOGON_NAME          varchar(180)       not null,
    FIRST_NAME          varchar(120)       not null,
    MIDDLE_NAME         varchar(60),
    LAST_NAME           varchar(120)       not null,
    PASSWORD            varchar(40),
    EMAIL_ADDRESS       varchar(240),
    EVENT_NOTIFICATION  smallint           not null  default 0,
    PHONE               varchar(40),
    FAX                 varchar(40),
    EXT_ID              varchar(80),
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);
insert into ADM.ADMINISTRATOR select * from ADM.ADMINISTRATOR1;
--password 'system' must be set to user 'tlmroot'
update ADM.ADMINISTRATOR set PASSWORD = '-6ad4e5fcc4ffb577478f940bc10fbc4f' where LOGON_NAME = 'tlmroot';
drop table ADM.ADMINISTRATOR1;

--indexes
alter table ADM.ADMINISTRATOR add constraint ADMINISTRATOR_PK primary key
(
    ID
);

create unique index ADM.ADMINISTRATOR_UI1 on ADM.ADMINISTRATOR
(
    LOGON_NAME
);

create unique index ADM.ADMINISTRATOR_UI2 on ADM.ADMINISTRATOR
(
    EXT_ID
);

-------------------------------------------------------------------------------
-- ADM.AGENT table dropping and re-creating:
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.AGENT1
(
    ID                  bigint             not null,
    HOSTNAME            varchar(60)        not null,
    IP_ADDRESS          varchar(20),
    VERSION             varchar(20)        not null,
    OS_NAME             varchar(10)        not null,
    OS_VERSION          varchar(60),
    MEMORY              integer            not null  default 0,
    DISKS               integer            not null  default 0,
    STORAGE             integer            not null  default 0,
    PROCESSORS          integer            not null  default 0,
    LPAR_NAME           varchar(96),
    LPAR_CAPACITY       integer            not null  default 0,
    POOL_NAME           varchar(48),
    POOL_CAPACITY       integer            not null  default 0,
    SECURITY_LEVEL      smallint           not null  default 1,
    PLUGIN_TIME         timestamp          not null  default CURRENT TIMESTAMP,
    LAST_SYNC_TIME      timestamp,
    SCAN_TIME           timestamp,
    ACTIVE              smallint           not null  default 1,
    SERVER_ID           bigint             not null,
    NODE_ID             bigint             not null,
    DIVISION_ID         bigint             not null,
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

-- without node agents are not valid, delete them and all of the references
delete from ADM.AGENT_EVENT where AGENT_ID in (select ID from ADM.AGENT where NODE_ID is null OR VERSION is null);
delete from ADM.AGENT_INV   where AGENT_ID in (select ID from ADM.AGENT where NODE_ID is null OR VERSION is null);

update ADM.AGENT_H
set END_TIME = CURRENT TIMESTAMP - CURRENT TIMEZONE,
    END_ACTION='D'
where ID in (select ID from ADM.AGENT where NODE_ID is null OR VERSION is null) AND
      END_TIME = '9999-12-31-00.00.00.000000';

delete from ADM.AGENT where NODE_ID is null OR VERSION is null;

-- security level is 1(HTTP), last_sync_time=plugin_time
insert into ADM.AGENT1(ID,
                       HOSTNAME,
                       IP_ADDRESS,
                       VERSION,
                       OS_NAME,
                       OS_VERSION,
                       MEMORY,
                       DISKS,
                       STORAGE,
                       PROCESSORS,
                       SECURITY_LEVEL,
                       PLUGIN_TIME,
                       SERVER_ID,
                       NODE_ID,
                       DIVISION_ID,
                       CUSTOMER_ID,
                       LAST_SYNC_TIME,
                       ACTIVE,
                       LAST_MODIFIED) select ID,
                                             HOSTNAME,
                                             IP_ADDRESS,
                                             VERSION,
                                             OS_NAME,
                                             OS_VERSION,
                                             MEMORY,
                                             DISKS,
                                             STORAGE,
                                             ONLINE_PROCS*100,
                                             1,
                                             PLUGIN_TIME,
                                             SERVER_ID,
                                             NODE_ID,
                                             DIVISION_ID,
                                             CUSTOMER_ID,
                                             PLUGIN_TIME,
                                             ACTIVE,
                                             LAST_MODIFIED
                                      from ADM.AGENT;

-- retrieve and fill last_scan_time info
-- put last scan_time in a temporary table
create table ADM.AGT_SCAN_TIME
(
    AGENT_ID            bigint             not null,
    SCAN_TIME           timestamp          not null
);

insert into ADM.AGT_SCAN_TIME select AGENT_ID, max(SCAN_TIME) from ADM.AGENT_INV group by AGENT_ID;

update ADM.AGENT1 as AG set SCAN_TIME = (select SCAN_TIME from ADM.AGT_SCAN_TIME WHERE AGENT_ID = AG.ID);
drop table ADM.AGT_SCAN_TIME;

--table substitution
drop table ADM.AGENT;
create table ADM.AGENT
(
    ID                  bigint             not null,
    HOSTNAME            varchar(60)        not null,
    IP_ADDRESS          varchar(20),
    VERSION             varchar(20)        not null,
    OS_NAME             varchar(10)        not null,
    OS_VERSION          varchar(60),
    MEMORY              integer            not null  default 0,
    DISKS               integer            not null  default 0,
    STORAGE             integer            not null  default 0,
    PROCESSORS          integer            not null  default 0,
    LPAR_NAME           varchar(96),
    LPAR_CAPACITY       integer            not null  default 0,
    POOL_NAME           varchar(48),
    POOL_CAPACITY       integer            not null  default 0,
    SECURITY_LEVEL      smallint           not null  default 1,
    PLUGIN_TIME         timestamp          not null  default CURRENT TIMESTAMP,
    LAST_SYNC_TIME      timestamp,
    SCAN_TIME           timestamp,
    ACTIVE              smallint           not null  default 1,
    SERVER_ID           bigint             not null,
    NODE_ID             bigint             not null,
    DIVISION_ID         bigint             not null,
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);
insert into ADM.AGENT select * from ADM.AGENT1;
drop table ADM.AGENT1;

--indexes
alter table ADM.AGENT add constraint AGENT_PK primary key
(
    ID
);

create index ADM.AGENT_I1 on ADM.AGENT
(
    DIVISION_ID
);

create index ADM.AGENT_I2 on ADM.AGENT
(
    NODE_ID
);

-------------------------------------------------------------------------------
-- ADM.AGENT_DIV_HREL table dropping
-------------------------------------------------------------------------------
drop table ADM.AGENT_DIV_HREL;

-------------------------------------------------------------------------------
-- ADM.AGENT_EVENT table dropping and re-creating:
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.AGENT_EVENT1
(
    AGENT_ID            bigint             not null,
    EVENT_ID            integer            not null,
    TIME                timestamp          not null
);

insert into ADM.AGENT_EVENT1(AGENT_ID,
                             EVENT_ID,
                             TIME) select AGENT_ID,
                                          EVENT_ID,
                                          TIME
                                          from ADM.AGENT_EVENT;

--table substitution
drop table ADM.AGENT_EVENT;
create table ADM.AGENT_EVENT
(
    AGENT_ID            bigint           not null,
    EVENT_ID            integer           not null,
    TIME                timestamp           not null
);
insert into ADM.AGENT_EVENT select * from ADM.AGENT_EVENT1;
drop table ADM.AGENT_EVENT1;

--indexes
alter table ADM.AGENT_EVENT add constraint AGENT_EVENT_PK primary key
(
    AGENT_ID,
    TIME
);

-------------------------------------------------------------------------------
-- ADM.AGENT_H table dropping and re-creating:
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.AGENT_H1
(
    ID                  bigint             not null,
    VERSION             varchar(20)        not null,
    OS_VERSION          varchar(60),
    SERVER_ID           bigint             not null,
    NODE_ID             bigint             not null,
    DIVISION_ID         bigint             not null,
    CUSTOMER_ID         bigint             not null,
    START_TIME          timestamp          not null,
    START_ACTION        char(1)            not null,
    END_TIME            timestamp          not null,
    END_ACTION          char(1)            not null
);

insert into ADM.AGENT_H1(ID,
                         VERSION,
                         SERVER_ID,
                         NODE_ID,
                         DIVISION_ID,
                         CUSTOMER_ID,
                         START_TIME,
                         START_ACTION,
                         END_TIME,
                         END_ACTION) select ID,
                                            '-',
                                            SERVER_ID,
                                            NODE_ID,
                                            DIVISION_ID,
                                            -ID,
                                            START_TIME,
                                            START_ACTION,
                                            END_TIME,
                                            END_ACTION
                                            from ADM.AGENT_H
                                            where END_TIME > CURRENT TIMESTAMP - 3 MONTH;

update ADM.AGENT_H1 as AH set VERSION = coalesce((select AG.VERSION
                                                 from ADM.AGENT AG
                                                 where AG.ID = AH.ID), '-');

update ADM.AGENT_H1 as AH set OS_VERSION = (select AG.OS_VERSION
                                            from ADM.AGENT AG
                                            where AG.ID = AH.ID);

--attempting retrieving customer_id info from agent, server, division and node tables
update ADM.AGENT_H1 as AH set CUSTOMER_ID = coalesce((select AG.CUSTOMER_ID
                                                      from ADM.AGENT AG
                                                      where AG.ID = AH.ID), AH.CUSTOMER_ID)
                                            where CUSTOMER_ID<0;
update ADM.AGENT_H1 as AH set CUSTOMER_ID = coalesce((select SV.CUSTOMER_ID
                                                      from ADM.SERVER SV
                                                      where AH.SERVER_ID = SV.ID), AH.CUSTOMER_ID)
                                            where CUSTOMER_ID<0;
update ADM.AGENT_H1 as AH set CUSTOMER_ID = coalesce((select DV.CUSTOMER_ID
                                                      from ADM.DIVISION DV
                                                      where AH.DIVISION_ID = DV.ID), AH.CUSTOMER_ID)
                                            where CUSTOMER_ID<0;
update ADM.AGENT_H1 as AH set CUSTOMER_ID = coalesce((select ND.CUSTOMER_ID
                                                      from ADM.NODE ND
                                                      where AH.NODE_ID = ND.ID), AH.CUSTOMER_ID)
                                            where CUSTOMER_ID<0;
--delete the ones with not still retrieved CUSTOMER_ID
delete from ADM.AGENT_H1 where CUSTOMER_ID<0;


--table substitution
drop table ADM.AGENT_H;
create table ADM.AGENT_H
(
    ID                  bigint             not null,
    VERSION             varchar(20)        not null,
    OS_VERSION          varchar(60),
    SERVER_ID           bigint             not null,
    NODE_ID             bigint             not null,
    DIVISION_ID         bigint             not null,
    CUSTOMER_ID         bigint             not null,
    START_TIME          timestamp          not null,
    START_ACTION        char(1)            not null,
    END_TIME            timestamp          not null,
    END_ACTION          char(1)            not null
);
insert into ADM.AGENT_H select * from ADM.AGENT_H1;
drop table ADM.AGENT_H1;

create index ADM.AGENT_H_I1 on ADM.AGENT_H
(
    ID
);

create index ADM.AGENT_H_I2 on ADM.AGENT_H
(
    DIVISION_ID
);

-------------------------------------------------------------------------------
-- ADM.AGENT_INV table dropping and re-creating:
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.AGENT_INV1
(
    ID                  bigint             not null,
    AGENT_ID            bigint             not null,
    COMPONENT_ID        bigint             not null,
    START_TIME          timestamp          not null,
    END_TIME            timestamp          not null
);

create sequence ADM.INV_SEQ as bigint start with 1;
insert into ADM.AGENT_INV1(ID,
                           AGENT_ID,
                           COMPONENT_ID,
                           START_TIME,
                           END_TIME) select nextval for ADM.INV_SEQ,
                                            AGENT_ID,
                                            COMPONENT_ID,
                                            START_TIME,
                                            END_TIME
                                            from ADM.AGENT_INV
                                            where END_TIME > CURRENT TIMESTAMP - 3 MONTH;
drop sequence ADM.INV_SEQ restrict;

--table substitution
drop table ADM.AGENT_INV;
create table ADM.AGENT_INV
(
    ID                  bigint             not null,
    AGENT_ID            bigint             not null,
    COMPONENT_ID        bigint             not null,
    START_TIME          timestamp          not null,
    END_TIME            timestamp          not null
);
insert into ADM.AGENT_INV select * from ADM.AGENT_INV1;
drop table ADM.AGENT_INV1;

--indexes
alter table ADM.AGENT_INV add constraint AGENT_INV_PK primary key
(
    ID
);

create unique index ADM.AGENT_INV_UI on ADM.AGENT_INV
(
    AGENT_ID,
    COMPONENT_ID,
    START_TIME
);

create index ADM.AGENT_INV_I1 on ADM.AGENT_INV
(
    COMPONENT_ID
);

-------------------------------------------------------------------------------
-- ADM.AGENT_INV_LIC new empty table
-------------------------------------------------------------------------------
create table ADM.AGENT_INV_LIC
(
    AGENT_INV_ID        bigint             not null,
    LICENSE_ID          bigint             not null,
    QUANTITY            integer            not null,
    START_TIME          timestamp          not null,
    END_TIME            timestamp          not null
);

alter table ADM.AGENT_INV_LIC add constraint AGENT_INV_LIC_PK primary key
(
    AGENT_INV_ID,
    START_TIME
);

create index ADM.AGENT_INV_LIC_I1 on ADM.AGENT_INV_LIC
(
    LICENSE_ID
);

-------------------------------------------------------------------------------
-- ADM.AGENT_SYNC_CUST new empty table
-------------------------------------------------------------------------------
create table ADM.AGENT_SYNC_CUST
(
    CUSTOMER_ID         bigint             not null,
    SYNC_DATE           date               not null,
    SYNC_RATIO          smallint           not null
);

alter table ADM.AGENT_SYNC_CUST add constraint AG_SYNC_CUS_PK primary key
(
    CUSTOMER_ID,
    SYNC_DATE
);

-------------------------------------------------------------------------------
-- ADM.AGENT_SYNC_DIV new empty table
-------------------------------------------------------------------------------
create table ADM.AGENT_SYNC_DIV
(
    DIVISION_ID         bigint             not null,
    SYNC_DATE           date               not null,
    SYNC_RATIO          smallint           not null
);

alter table ADM.AGENT_SYNC_DIV add constraint AG_SYNC_DIV_PK primary key
(
    DIVISION_ID,
    SYNC_DATE
);

-------------------------------------------------------------------------------
-- ADM.CATEGORY table dropping
-------------------------------------------------------------------------------
drop table ADM.CATEGORY;

-------------------------------------------------------------------------------
-- ADM.COMMAND table dropping
-------------------------------------------------------------------------------
drop table ADM.COMMAND;

-------------------------------------------------------------------------------
-- ADM.COMP_MOD_REL table moves to SWCAT schema;
-------------------------------------------------------------------------------
-- new table and filling
create table SWCAT.COMP_MOD_REL
(
    COMPONENT_ID        bigint             not null,
    MODULE_ID           bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

alter table SWCAT.COMP_MOD_REL add constraint COMP_MOD_REL_PK primary key
(
    COMPONENT_ID,
    MODULE_ID
);

insert into SWCAT.COMP_MOD_REL select * from ADM.COMP_MOD_REL;

--old table dropped and new synonym
drop table ADM.COMP_MOD_REL;
create synonym ADM.COMP_MOD_REL for SWCAT.COMP_MOD_REL;


-------------------------------------------------------------------------------
-- ADM.COMPONENT table moves to SWCAT schema;
-------------------------------------------------------------------------------
--manage duplicate EXT_ID
update ADM.COMPONENT as CM
set EXT_ID = rtrim('TLM_' concat
                   (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                   '_' concat
                   char(CM.ID))
where EXT_ID in (select EXT_ID
                 from ADM.COMPONENT
                 group by EXT_ID
                 having count(EXT_ID) > 1) or
      EXT_ID is null;

-- new table and filling
create table SWCAT.COMPONENT
(
    ID                  bigint             not null,
    NAME                varchar(240)       not null,
    VERSION             varchar(64)        not null,
    TREE_LEVEL          smallint           not null  default 3,
    OS_NAME             varchar(12)        not null,
    LEVEL_              smallint           not null  default 2,
    IS_IBM              smallint           not null  default 0,
    DESCRIPTION         varchar(300),
    VENDOR_ID           bigint             not null  default 1,
    COMPONENT_ID        bigint,
    EXT_ID              varchar(40)        not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

alter table SWCAT.COMPONENT add constraint COMPONENT_PK primary key
(
    ID
);

create unique index SWCAT.COMPONENT_UI1 on SWCAT.COMPONENT
(
    NAME,
    VERSION,
    OS_NAME
);

create unique index SWCAT.COMPONENT_UI2 on SWCAT.COMPONENT
(
    EXT_ID
);

create index SWCAT.COMPONENT_I1 on SWCAT.COMPONENT
(
    VENDOR_ID
);

--tree level is 3, IS_IBM is ignored (set by finalization phase)
insert into SWCAT.COMPONENT (ID,
                             NAME,
                             VERSION,
                             TREE_LEVEL,
                             OS_NAME,
                             LEVEL_,
                             DESCRIPTION,
                             VENDOR_ID,
                             COMPONENT_ID,
                             EXT_ID,
                             LAST_MODIFIED)
                             select ID,
                                    NAME,
                                    VERSION,
                                    3,
                                    OS_NAME,
                                    LEVEL,
                                    DESCRIPTION,
                                    VENDOR_ID,
                                    COMPONENT_ID,
                                    EXT_ID,
                                    LAST_MODIFIED from ADM.COMPONENT;

--old table dropped and new synonym
drop table ADM.COMPONENT;
create synonym ADM.COMPONENT for SWCAT.COMPONENT;


-------------------------------------------------------------------------------
-- ADM.COMP_HIER new table must be created and filled;
-------------------------------------------------------------------------------
create table SWCAT.COMP_HIER
(
    RELEASE_ID          bigint             not null,
    VERSION_ID          bigint,
    PRODUCT_ID          bigint
);
insert into SWCAT.COMP_HIER (RELEASE_ID)
                             select ID from SWCAT.COMPONENT;

alter table SWCAT.COMP_HIER add constraint COMP_HIER_PK primary key
(
    RELEASE_ID
);

create index SWCAT.COMP_HIER_I1 on SWCAT.COMP_HIER
(
    VERSION_ID
);

create index SWCAT.COMP_HIER_I2 on SWCAT.COMP_HIER
(
    PRODUCT_ID
);

create synonym ADM.COMP_HIER for SWCAT.COMP_HIER;

-------------------------------------------------------------------------------
-- ADM.CONTRACT new empty table
-------------------------------------------------------------------------------
create table ADM.CONTRACT
(
    ID                  bigint             not null,
    CONTRACT_NUM        varchar(120)       not null,
    TYPE                integer            not null,
    STATUS              integer            not null  default 1,
    SUPPLY_VENDOR       varchar(120),
    PURCHASE_VENDOR     varchar(120),
    OWNER               varchar(120),
    START_DATE          timestamp          not null,
    END_DATE            timestamp          not null  default '9999-12-31-00.00.00.0',
    COST                decimal(14,2)      not null  default 0,
    COST_CURR           char(3),
    TERMS               long varchar,
    NOTES               long varchar,
    MODIFIED_BY         varchar(60),
    EXT_ID              varchar(80),
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null
);

alter table ADM.CONTRACT add constraint CONTRACT_PK primary key
(
    ID
);

create unique index ADM.CONTRACT_UI1 on ADM.CONTRACT
(
    CONTRACT_NUM,
    CUSTOMER_ID
);

create unique index ADM.CONTRACT_UI2 on ADM.CONTRACT
(
    EXT_ID,
    CUSTOMER_ID
);

-------------------------------------------------------------------------------
-- ADM.CONTROL new entries, updated entries and dropped ones - new SWCAT.CONTROL
-------------------------------------------------------------------------------
insert into ADM.CONTROL (NAME, VALUE) values ('LAST_AGGREGATE_STEP', '0');
insert into ADM.CONTROL (NAME, VALUE) values ('MIGRATION_TIME',  char(date(current timestamp - current timezone), jis) concat ' ' concat char(time(current timestamp - current timezone), jis) concat '.0');
insert into ADM.CONTROL (NAME, VALUE) values ('FIRST_TO_AGGREGATE_DAY',  substr(char(current timestamp -  current timezone), 1, 10));

update adm.control set VALUE=(char(date(timestamp(VALUE)), JIS) concat ' ' concat char(time(timestamp(VALUE)), JIS) concat '.0') where NAME='DB_CREATION';
update adm.control set VALUE=(char(date(timestamp(VALUE)), JIS) concat ' ' concat char(time(timestamp(VALUE)), JIS) concat '.0') where NAME='LAST_SERVERS_WAKE_UP_TIME';
update adm.control set VALUE=(char(date(timestamp(VALUE)), JIS) concat ' ' concat char(time(timestamp(VALUE)), JIS) concat '.0') where NAME='CATALOG_UPDATE';
update adm.control set VALUE=(char(date(timestamp(VALUE)), JIS) concat ' ' concat char(time(timestamp(VALUE)), JIS) concat '.0') where NAME='CATALOG_INSTALL';
update adm.control set VALUE='2.1' where NAME='DATABASE_VERSION';

create table SWCAT.CONTROL
(
    NAME                varchar(40)        not null,
    VALUE               varchar(60)        not null
);

alter table SWCAT.CONTROL add constraint CONTROL_PK primary key
(
    NAME
);

insert into SWCAT.CONTROL (NAME, VALUE) select 'CATALOG_INSTALL', VALUE from adm.control WHERE name='CATALOG_INSTALL';
insert into SWCAT.CONTROL (NAME, VALUE) values ('DATABASE_VERSION', '2.1');
insert into SWCAT.CONTROL (NAME, VALUE) values ('CATALOG_UPDATE',   '2002-05-01 12:00:00.000000');
insert into SWCAT.CONTROL (NAME, VALUE) values ('CATALOG_ID',       substr(char(current timestamp), 21, 2) concat
                                                                    substr(char(current timestamp), 18, 2) concat
                                                                    substr(char(current timestamp), 15, 2));
insert into SWCAT.CONTROL (NAME, VALUE) values ('IBM_USE_ONLY',   'false');
insert into SWCAT.CONTROL (NAME, VALUE) values ('CATALOG_LAST_MODIFIED',   current timestamp);


delete from ADM.CONTROL where NAME='LAST_USAGE_HWM_SCAN_TIME' or
                              NAME = 'LAST_CLEAN_USAGE_TIME' or
                              NAME = 'CATALOG_INSTALL' or
                              NAME = 'CATALOG_UPDATE';

-- synonym
create synonym ADM.SWCAT_CONTROL for SWCAT.CONTROL;

-------------------------------------------------------------------------------
-- ADM.COUNTRY unique index must be renamed
-------------------------------------------------------------------------------
drop index ADM.COUNTRY_UI;
create unique index ADM.COUNTRY_UI1 on ADM.COUNTRY
(
    NAME
);

-------------------------------------------------------------------------------
-- ADM.CUST_OPT_FIELD new empty table
-------------------------------------------------------------------------------
create table ADM.CUST_OPT_FIELD
(
    OPT_FIELD_ID        bigint             not null,
    CUSTOMER_ID         bigint             not null
);

alter table ADM.CUST_OPT_FIELD add constraint CUST_OPT_FIELD_PK primary key
(
    OPT_FIELD_ID,
    CUSTOMER_ID
);

-------------------------------------------------------------------------------
-- ADM.CUSTOMER dropping and re-creating:
-------------------------------------------------------------------------------
-- code country management
-- set null if not equal to any code
update ADM.CUSTOMER set COUNTRY_CODE = null WHERE substr(upper(COUNTRY_CODE),1,2) not in
                                                        (select upper(ISO_CODE2) from ADM.COUNTRY) and
                                                  substr(upper(COUNTRY_CODE),1,3) not in
                                                        (select upper(ISO_CODE3) from ADM.COUNTRY) and
                                                  substr(upper(COUNTRY_CODE),1,3) not in
                                                        (select upper(ISO_CODE4) from ADM.COUNTRY);
-- set to the corresponding iso_code3 (the only one the WUI uses)
update ADM.CUSTOMER CS set COUNTRY_CODE = (
                                            select ISO_CODE3 from ADM.COUNTRY CN where
                                                  (substr(upper(CS.COUNTRY_CODE),1,2) = upper(CN.ISO_CODE2)) or
                                                  (substr(upper(CS.COUNTRY_CODE),1,3) = upper(CN.ISO_CODE3)) or
                                                  (substr(upper(CS.COUNTRY_CODE),1,3) = upper(CN.ISO_CODE4))
                                          ) where COUNTRY_CODE is not null;

-- temporary table and filling
create table ADM.CUSTOMER1
(
    ID                  bigint             not null,
    NAME                varchar(120)       not null,
    ACCOUNT_ID          varchar(63),
    COUNTRY_CODE        char(3),
    DESCRIPTION         varchar(600),
    CHECK_PERIOD        bigint             not null  default 0,
    REQUEST_SCOPE       integer            not null  default 0,
    SECURITY_LEVEL      smallint           not null  default 1,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);


-- security level is 1(HTTP), insert for country_code null and not
insert into ADM.CUSTOMER1(ID,
                          NAME,
                          ACCOUNT_ID,
                          COUNTRY_CODE,
                          DESCRIPTION,
                          CHECK_PERIOD,
                          REQUEST_SCOPE,
                          SECURITY_LEVEL,
                          LAST_MODIFIED) select ID,
                                             NAME,
                                             ACCOUNT_ID,
                                             substr(COUNTRY_CODE,1,3),
                                             DESCRIPTION,
                                             CHECK_PERIOD,
                                             REQUEST_SCOPE,
                                             1,
                                             LAST_MODIFIED
                                         from ADM.CUSTOMER where COUNTRY_CODE is not null;
insert into ADM.CUSTOMER1(ID,
                          NAME,
                          ACCOUNT_ID,
                          COUNTRY_CODE,
                          DESCRIPTION,
                          CHECK_PERIOD,
                          REQUEST_SCOPE,
                          SECURITY_LEVEL,
                          LAST_MODIFIED) select ID,
                                             NAME,
                                             ACCOUNT_ID,
                                             COUNTRY_CODE,
                                             DESCRIPTION,
                                             CHECK_PERIOD,
                                             REQUEST_SCOPE,
                                             1,
                                             LAST_MODIFIED
                                         from ADM.CUSTOMER where COUNTRY_CODE is null;

--table substitution
drop table ADM.CUSTOMER;
create table ADM.CUSTOMER
(
    ID                  bigint             not null,
    NAME                varchar(120)       not null,
    ACCOUNT_ID          varchar(63),
    COUNTRY_CODE        char(3),
    DESCRIPTION         varchar(600),
    CHECK_PERIOD        bigint             not null  default 0,
    REQUEST_SCOPE       integer            not null  default 0,
    SECURITY_LEVEL      smallint           not null  default 1,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);
insert into ADM.CUSTOMER select * from ADM.CUSTOMER1;
drop table ADM.CUSTOMER1;

--indexes
alter table ADM.CUSTOMER add constraint CUSTOMER_PK primary key
(
    ID
);

create unique index ADM.CUSTOMER_UI1 on ADM.CUSTOMER
(
    NAME
);

-------------------------------------------------------------------------------
-- ADM.DIVISION table dropping and recreating.
-------------------------------------------------------------------------------
create table ADM.DIVISION1
(
    ID                  bigint             not null,
    NAME                varchar(120)       not null,
    INV_START_DATE      timestamp          not null  default CURRENT TIMESTAMP,
    INV_RATE_TYPE       smallint           not null  default 0,
    INV_RATE_VALUE      integer            not null  default 1,
    DESCRIPTION         varchar(600),
    SECURITY_LEVEL      smallint           not null  default 0,
    EXT_ID              varchar(80),
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

--reset EXT_ID
update ADM.DIVISION as DV
set EXT_ID = rtrim('TLM_' concat
                   (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                   '_' concat
                   char(DV.ID));

insert into ADM.DIVISION1(ID,
                          NAME,
                          INV_START_DATE,
                          INV_RATE_TYPE,
                          INV_RATE_VALUE,
                          DESCRIPTION,
                          EXT_ID,
                          CUSTOMER_ID,
                          LAST_MODIFIED) select ID,
                                                NAME,
                                                INV_START_DATE,
                                                INV_RATE_TYPE,
                                                INV_RATE_VALUE,
                                                DESCRIPTION,
                                                EXT_ID,
                                                CUSTOMER_ID,
                                                LAST_MODIFIED
                                           from ADM.DIVISION;

drop table ADM.DIVISION;
create table ADM.DIVISION
(
    ID                  bigint             not null,
    NAME                varchar(120)       not null,
    INV_START_DATE      timestamp          not null  default CURRENT TIMESTAMP,
    INV_RATE_TYPE       smallint           not null  default 0,
    INV_RATE_VALUE      integer            not null  default 1,
    DESCRIPTION         varchar(600),
    SECURITY_LEVEL      smallint           not null  default 0,
    EXT_ID              varchar(80),
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

insert into ADM.DIVISION select * from ADM.DIVISION1;
drop table ADM.DIVISION1;

--indexes
alter table ADM.DIVISION add constraint DIVISION_PK primary key
(
    ID
);

create unique index ADM.DIVISION_UI1 on ADM.DIVISION
(
    NAME,
    CUSTOMER_ID
);

create unique index ADM.DIVISION_UI2 on ADM.DIVISION
(
    EXT_ID,
    CUSTOMER_ID
);

-------------------------------------------------------------------------------
-- ADM.DIVISION_H table dropping and re-creating:
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.DIVISION_H1
(
    ID                  bigint             not null,
    NAME                varchar(120)       not null,
    INV_START_DATE      timestamp          not null,
    INV_RATE_TYPE       smallint           not null,
    INV_RATE_VALUE      integer            not null,
    DESCRIPTION         varchar(600),
    SECURITY_LEVEL      smallint           not null,
    CUSTOMER_ID         bigint             not null,
    START_TIME          timestamp          not null,
    START_ACTION        char(1)            not null,
    END_TIME            timestamp          not null,
    END_ACTION          char(1)            not null
);

-- security level = 0 - inherits
insert into ADM.DIVISION_H1(ID,
                            NAME,
                            INV_START_DATE,
                            INV_RATE_TYPE,
                            INV_RATE_VALUE,
                            DESCRIPTION,
                            SECURITY_LEVEL,
                            CUSTOMER_ID,
                            START_TIME,
                            START_ACTION,
                            END_TIME,
                            END_ACTION) select ID,
                                               NAME,
                                               INV_START_DATE,
                                               INV_RATE_TYPE,
                                               INV_RATE_VALUE,
                                               DESCRIPTION,
                                               0,
                                               CUSTOMER_ID,
                                               START_TIME,
                                               START_ACTION,
                                               END_TIME,
                                               END_ACTION
                                        from ADM.DIVISION_H
                                        where END_TIME > CURRENT TIMESTAMP - 3 MONTH;

--table substitution
drop table ADM.DIVISION_H;
create table ADM.DIVISION_H
(
    ID                  bigint             not null,
    NAME                varchar(120)       not null,
    INV_START_DATE      timestamp          not null,
    INV_RATE_TYPE       smallint           not null,
    INV_RATE_VALUE      integer            not null,
    DESCRIPTION         varchar(600),
    SECURITY_LEVEL      smallint           not null,
    CUSTOMER_ID         bigint             not null,
    START_TIME          timestamp          not null,
    START_ACTION        char(1)            not null,
    END_TIME            timestamp          not null,
    END_ACTION          char(1)            not null
);
insert into ADM.DIVISION_H select * from ADM.DIVISION_H1;
drop table ADM.DIVISION_H1;

create index ADM.DIVISION_H_I1 on ADM.DIVISION_H
(
    ID
);

-------------------------------------------------------------------------------
-- ADM.ENDUSER table altering:
-------------------------------------------------------------------------------
-- manage duplicates (could be only null) for unique indexes
update ADM.ENDUSER as EU set LOGON_NAME= 'MIGRATION_' concat rtrim(char(EU.ID))
                         where LOGON_NAME is null;
--reset EXT_ID
update ADM.ENDUSER as EU
set EXT_ID=rtrim('TLM_' concat
                 (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                 '_' concat
                 char(EU.ID));

-- enlarge fields
alter table ADM.ENDUSER alter column LOGON_NAME     set data type varchar(120);
alter table ADM.ENDUSER alter column EMPLOYEE_NO    set data type varchar(60);
alter table ADM.ENDUSER alter column EMAIL_ADDRESS  set data type varchar(240);
alter table ADM.ENDUSER alter column LOCATION       set data type varchar(240);

-- indexes
drop index adm.enduser_i;
create unique index ADM.ENDUSER_UI1 on ADM.ENDUSER
(
    CUSTOMER_ID,
    LOGON_NAME
);

create unique index ADM.ENDUSER_UI2 on ADM.ENDUSER
(
    EXT_ID,
    CUSTOMER_ID
);

-------------------------------------------------------------------------------
-- ADM.ENTITLEMENT table dropping and re-creating:
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.ENTITLEMENT1
(
    ID                  bigint             not null,
    COMPONENT_ID        bigint             not null,
    CUSTOMER_ID         bigint             not null,
    ACTIVE              smallint           not null  default 0,
    LICENSE_CONTROL     smallint           not null  default 0,
    NEED_RESPONSE       smallint           not null  default 0,
    RUN_OFFLINE         smallint           not null  default 1,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

insert into ADM.ENTITLEMENT1 select * from ADM.ENTITLEMENT;
--overwrite invalid LICENSE_CONTROL - NEED_RESPONSE combination
update ADM.ENTITLEMENT1 EN set LICENSE_CONTROL = 0 where NEED_RESPONSE = 0;

--table substitution
drop table ADM.ENTITLEMENT;
create table ADM.ENTITLEMENT
(
    ID                  bigint             not null,
    COMPONENT_ID        bigint             not null,
    CUSTOMER_ID         bigint             not null,
    ACTIVE              smallint           not null  default 0,
    LICENSE_CONTROL     smallint           not null  default 0,
    NEED_RESPONSE       smallint           not null  default 0,
    RUN_OFFLINE         smallint           not null  default 1,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);
insert into ADM.ENTITLEMENT select * from ADM.ENTITLEMENT1;
drop table ADM.ENTITLEMENT1;

-- indexes
alter table ADM.ENTITLEMENT add constraint ENTITLEMENT_PK primary key
(
    ID
);

create unique index ADM.ENTITLEMENT_UI1 on ADM.ENTITLEMENT
(
    CUSTOMER_ID,
    COMPONENT_ID
);

-------------------------------------------------------------------------------
-- ADM.INV_H_COMP new empty table
-------------------------------------------------------------------------------
create table ADM.INV_H_COMP
(
    ID                  bigint             not null,
    CUSTOMER_ID         bigint             not null,
    COMPONENT_ID        bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null,
    UNLICENSED_HWM      integer            not null,
    RIF_HWM             integer            not null
);

alter table ADM.INV_H_COMP add constraint INV_H_COMP_PK primary key
(
    CUSTOMER_ID,
    COMPONENT_ID,
    DATE_USAGE
);


-------------------------------------------------------------------------------
-- ADM.INV_H_LIC new empty table
-------------------------------------------------------------------------------
create table ADM.INV_H_LIC
(
    ID                  bigint             not null,
    LICENSE_ID          bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null
);

alter table ADM.INV_H_LIC add constraint INV_H_LIC_PK primary key
(
    LICENSE_ID,
    DATE_USAGE
);

-------------------------------------------------------------------------------
-- ADM.INV_H_LIC_COMP new empty table
-------------------------------------------------------------------------------
create table ADM.INV_H_LIC_COMP
(
    ID                  bigint             not null,
    LICENSE_ID          bigint             not null,
    COMPONENT_ID        bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null
);

alter table ADM.INV_H_LIC_COMP add constraint INV_H_L_CMP_PK primary key
(
    LICENSE_ID,
    COMPONENT_ID,
    DATE_USAGE
);

-------------------------------------------------------------------------------
-- ADM.INV_H_PLIC new empty table
-------------------------------------------------------------------------------
create table ADM.INV_H_PLIC
(
    ID                  bigint             not null,
    PLICENSE_ID         bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null
);

alter table ADM.INV_H_PLIC add constraint INV_H_PLIC_PK primary key
(
    PLICENSE_ID,
    DATE_USAGE
);

-------------------------------------------------------------------------------
-- ADM.INV_H_PLIC_COMP new empty table
-------------------------------------------------------------------------------
create table ADM.INV_H_PLIC_COMP
(
    ID                  bigint             not null,
    PLICENSE_ID         bigint             not null,
    COMPONENT_ID        bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null
);

alter table ADM.INV_H_PLIC_COMP add constraint INV_H_PL_CMP_PK primary key
(
    PLICENSE_ID,
    COMPONENT_ID,
    DATE_USAGE
);

-------------------------------------------------------------------------------
-- ADM.LIC_TARGET_H table renaming
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.LIC_TARGET_HREL
(
    LICENSE_ID          bigint             not null,
    TARGET_ID           bigint             not null,
    START_TIME          timestamp          not null,
    END_TIME            timestamp          not null
);

insert into ADM.LIC_TARGET_HREL select *
                                from ADM.LIC_TARGET_H
                                where END_TIME > CURRENT TIMESTAMP - 3 MONTH;
drop table ADM.LIC_TARGET_H;

-------------------------------------------------------------------------------
-- ADM.LICENSE table dropping and re-creating:
-------------------------------------------------------------------------------
--create one procured license for every license
create table ADM.PLICENSE
(
    ID                  bigint             not null,
    REF_CODE            char(22)           not null,
    TREE_LEVEL          smallint           not null,
    SOFTWARE_NAME       varchar(240)       not null,
    OWNER               varchar(240),
    LICENSE_TYPE        integer            not null  default 1,
    QUANTITY            integer            not null,
    CAPACITY_TYPE       integer            not null,
    PURCHASE_TYPE       integer            not null  default 0,
    COST                decimal(14,2)      not null  default 0,
    COST_CURR           char(3),
    DELIVERY_DATE       timestamp          not null  default CURRENT TIMESTAMP,
    START_DATE          timestamp          not null,
    EXPIRATION_DATE     timestamp          not null  default '9999-12-31-00.00.00.0',
    CONTRACT_REF        varchar(120),
    ORDER_REF           varchar(120),
    LICENSE_KEY         varchar(60),
    TC                  long varchar,
    NOTES               long varchar,
    HARD_STOP           smallint           not null  default 0,
    MULTI_INSTANCE      smallint           not null  default 0,
    THRESHOLD           integer            not null  default 80,
    VERIFIED            smallint           not null  default 0,
    EXT_ID              varchar(80),
    CUSTOMER_ID         bigint             not null,
    MODIFIED_BY         varchar(60),
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

alter table ADM.PLICENSE add constraint PLICENSE_PK primary key
(
    ID
);

create unique index ADM.PLICENSE_UI1 on ADM.PLICENSE
(
    REF_CODE,
    CUSTOMER_ID
);

create unique index ADM.PLICENSE_UI2 on ADM.PLICENSE
(
    EXT_ID,
    CUSTOMER_ID
);

-- plicense filled: 1 plicense for every license, tree_level 3 (release), type 'concurrent network'
--                  ref code generated, cap type 'configured procs'->'procs'
insert into ADM.PLICENSE(ID,
                         REF_CODE,
                         TREE_LEVEL,
                         SOFTWARE_NAME,
                         LICENSE_TYPE,
                         QUANTITY,
                         CAPACITY_TYPE,
                         DELIVERY_DATE,
                         START_DATE,
                         EXPIRATION_DATE,
                         NOTES,
                         HARD_STOP,
                         MULTI_INSTANCE,
                         THRESHOLD,
                         EXT_ID,
                         CUSTOMER_ID,
                         MODIFIED_BY)
                          select L.ID,
                                 substr(char(year(CURRENT DATE)),3,2)
                                 concat substr(digits(month(CURRENT DATE)),9,2)
                                 concat substr(digits(day(CURRENT DATE)),9,2)
                                 concat '_N_'
                                 concat case
                                          when L.CAPACITY_TYPE=0 then 'U'
                                          when L.CAPACITY_TYPE=1 then 'M'
                                          when L.CAPACITY_TYPE=2 then 'P'
                                          when L.CAPACITY_TYPE=3 then 'P'
                                          when L.CAPACITY_TYPE=4 then 'D'
                                        end
                                 concat '_' concat char(L.ID),
                                 3,
                                 C.NAME,
                                 7,
                                 case
                                   when L.CAPACITY_TYPE=3 then L.QUANTITY*100
                                   when L.CAPACITY_TYPE=2 then L.QUANTITY*100
                                   else L.QUANTITY
                                 end,
                                 case
                                   when L.CAPACITY_TYPE=3 then 2
                                   else L.CAPACITY_TYPE
                                 end,
                                 L.START_DATE,
                                 L.START_DATE,
                                 L.EXPIRATION_DATE,
                                 L.DESCRIPTION,
                                 L.HARD_STOP,
                                 L.MULTI_INSTANCE,
                                 L.THRESHOLD,
                                 'TLM_' concat
                                   (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                                   '_' concat
                                   char(L.ID),
                                 L.CUSTOMER_ID,
                                 '-'
                         from ADM.LICENSE L, ADM.COMPONENT C
                         where L.COMPONENT_ID=C.ID;

--the same for plic_comp_rel
create table ADM.PLIC_COMP_REL
(
    PLICENSE_ID         bigint             not null,
    COMPONENT_ID        bigint             not null
);

alter table ADM.PLIC_COMP_REL add constraint PLIC_COMP_REL_PK primary key
(
    PLICENSE_ID,
    COMPONENT_ID
);

--created licenses - components relationship
insert into ADM.PLIC_COMP_REL select L.ID, L.COMPONENT_ID
                              from ADM.LICENSE L;

--reset EXT_ID
update ADM.LICENSE as LC
set EXT_ID = rtrim('TLM_' concat
                   (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                   '_' concat
                   char(LC.ID));

-- temporary table and filling
create table ADM.LICENSE1
(
    ID                  bigint             not null,
    REF_CODE            char(25)           not null,
    QUANTITY            integer            not null,
    TARGET_TYPE         integer            not null  default 1,
    ALL_TARGETS         smallint           not null  default 1,
    ALL_USERS           smallint           not null  default 1,
    PLICENSE_ID         bigint             not null,
    EXT_ID              varchar(80),
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

insert into ADM.LICENSE1 (ID,
                          REF_CODE,
                          QUANTITY,
                          TARGET_TYPE,
                          PLICENSE_ID,
                          EXT_ID,
                          CUSTOMER_ID,
                          LAST_MODIFIED) select L.ID,
                                                P.REF_CODE,
                                                case
                                                  when L.CAPACITY_TYPE=3 then L.QUANTITY*100
                                                  when L.CAPACITY_TYPE=2 then L.QUANTITY*100
                                                  else L.QUANTITY
                                                end,
                                                L.TARGET_TYPE,
                                                P.ID,
                                                L.EXT_ID,
                                                L.CUSTOMER_ID,
                                                L.LAST_MODIFIED
                                         from ADM.LICENSE L, ADM.PLICENSE P
                                         where L.ID = P.ID;
-- all targets/all users setting
update ADM.LICENSE1 as L set ALL_TARGETS = case
                                             when L.TARGET_TYPE = 1 then 1
                                             else 0
                                           end;
update ADM.LICENSE1 as L set ALL_USERS = coalesce ((select 0
                                                    from SYSIBM.SYSDUMMY1
                                                    where exists(select LICENSE_ID
                                                    from ADM.LIC_USER_REL LU
                                                    where L.ID = LU.LICENSE_ID)), 1);

--table substitution
drop table ADM.LICENSE;
create table ADM.LICENSE
(
    ID                  bigint             not null,
    REF_CODE            char(25)           not null,
    QUANTITY            integer            not null,
    TARGET_TYPE         integer            not null  default 1,
    ALL_TARGETS         smallint           not null  default 1,
    ALL_USERS           smallint           not null  default 1,
    PLICENSE_ID         bigint             not null,
    EXT_ID              varchar(80),
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);
insert into ADM.LICENSE select * from ADM.LICENSE1;
drop table ADM.LICENSE1;

-- indexes
alter table ADM.LICENSE add constraint LICENSE_PK primary key
(
    ID
);

create unique index ADM.LICENSE_UI1 on ADM.LICENSE
(
    REF_CODE,
    CUSTOMER_ID
);

create unique index ADM.LICENSE_UI2 on ADM.LICENSE
(
    EXT_ID,
    CUSTOMER_ID
);

-------------------------------------------------------------------------------
-- ADM.LICENSE_DISTRIBUTION table altering..
-------------------------------------------------------------------------------
alter table ADM.LICENSE_DISTRIBUTION
  add column LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP;

-- revoke generic grant
revoke all privileges on table ADM.LICENSE_DISTRIBUTION from tlmsrv;

-------------------------------------------------------------------------------
-- ADM.LICENSE_H table dropping and re-creating:
-------------------------------------------------------------------------------
--create one historical procured license for every license
create table ADM.PLICENSE_H
(
    ID                  bigint             not null,
    REF_CODE            char(22)           not null,
    TREE_LEVEL          smallint           not null,
    SOFTWARE_NAME       varchar(240)       not null,
    LICENSE_TYPE        integer            not null,
    QUANTITY            integer            not null,
    CAPACITY_TYPE       integer            not null,
    DELIVERY_DATE       timestamp          not null,
    START_DATE          timestamp          not null,
    EXPIRATION_DATE     timestamp          not null,
    HARD_STOP           smallint           not null,
    MULTI_INSTANCE      smallint           not null,
    THRESHOLD           integer            not null,
    CUSTOMER_ID         bigint             not null,
    START_TIME          timestamp          not null,
    START_ACTION        char(1)            not null,
    END_TIME            timestamp          not null,
    END_ACTION          char(1)            not null
);

-- plicense_h filled: 1 plicense_h for every license_h, tree_level 3 (release), type 'concurrent network'
--                    ref code generated, cap type 'configured procs'->'procs'
insert into ADM.PLICENSE_H(ID,
                           REF_CODE,
                           TREE_LEVEL,
                           SOFTWARE_NAME,
                           LICENSE_TYPE,
                           QUANTITY,
                           CAPACITY_TYPE,
                           DELIVERY_DATE,
                           START_DATE,
                           EXPIRATION_DATE,
                           HARD_STOP,
                           MULTI_INSTANCE,
                           THRESHOLD,
                           CUSTOMER_ID,
                           START_TIME,
                           START_ACTION,
                           END_TIME,
                           END_ACTION)
                          select LH.ID,
                                 substr(char(year(CURRENT DATE)),3,2)
                                 concat substr(digits(month(CURRENT DATE)),9,2)
                                 concat substr(digits(day(CURRENT DATE)),9,2)
                                 concat '_N_'
                                 concat case
                                          when LH.CAPACITY_TYPE=0 then 'U'
                                          when LH.CAPACITY_TYPE=1 then 'M'
                                          when LH.CAPACITY_TYPE=2 THEN 'P'
                                          when LH.CAPACITY_TYPE=3 then 'P'
                                          when LH.CAPACITY_TYPE=4 then 'D'
                                        end
                                 concat '_' concat char(LH.ID),
                                 3,
                                 C.NAME,
                                 7,
                                 case
                                   when LH.CAPACITY_TYPE=3 then LH.QUANTITY*100
                                   when LH.CAPACITY_TYPE=2 then LH.QUANTITY*100
                                   else LH.QUANTITY
                                 end,
                                 case
                                   when LH.CAPACITY_TYPE=3 then 2
                                   else LH.CAPACITY_TYPE
                                 end,
                                 LH.START_DATE,
                                 LH.START_DATE,
                                 LH.EXPIRATION_DATE,
                                 LH.HARD_STOP,
                                 LH.MULTI_INSTANCE,
                                 LH.THRESHOLD,
                                 LH.CUSTOMER_ID,
                                 LH.START_TIME,
                                 'I',
                                 LH.END_TIME,
                                 case
                                   when LH.END_TIME = '9999-12-31-00.00.00.000000' then ''
                                   else 'U'
                                 end
                         from ADM.LICENSE_H LH, ADM.COMPONENT C
                         where LH.COMPONENT_ID=C.ID
                           and LH.END_TIME > CURRENT TIMESTAMP - 3 MONTH;

-- change 'I' in 'U' as start_action whenever necessary (another row exists)
update ADM.PLICENSE_H PH set START_ACTION='U' where START_TIME <> (select min(START_TIME)
                                                                   from ADM.PLICENSE_H
                                                                   where ID = PH.ID)
                                                and START_ACTION <>'U';
-- change 'U' in 'D' as end_action whenever necessary (no more rows exist)
update ADM.PLICENSE_H PH set END_ACTION='D' where END_ACTION='U' and
                                                  END_TIME = (select max(END_TIME)
                                                              from ADM.PLICENSE_H
                                                              where ID = PH.ID);

create index ADM.PLICENSE_H_I1 on ADM.PLICENSE_H
(
    ID
);

--the same for plic_comp_hrel
create table ADM.PLIC_COMP_HREL
(
    PLICENSE_ID         bigint             not null,
    COMPONENT_ID        bigint             not null,
    START_TIME          timestamp          not null,
    END_TIME            timestamp          not null
);

-- created licenses - components historical relationship
insert into ADM.PLIC_COMP_HREL select LH.ID,
                                      LH.COMPONENT_ID,
                                      LH.START_TIME,
                                      LH.END_TIME
                                from  ADM.LICENSE_H LH
                                where LH.END_TIME > CURRENT TIMESTAMP - 3 MONTH;

-- temporary table and filling
create table ADM.LICENSE_H1
(
    ID                  bigint             not null,
    REF_CODE            char(25)           not null,
    QUANTITY            integer            not null,
    TARGET_TYPE         integer            not null,
    ALL_TARGETS         smallint           not null,
    ALL_USERS           smallint           not null,
    PLICENSE_ID         bigint             not null,
    CUSTOMER_ID         bigint             not null,
    START_TIME          timestamp          not null,
    START_ACTION        char(1)            not null,
    END_TIME            timestamp          not null,
    END_ACTION          char(1)            not null
);

-- initially set all targets no and all users yes
insert into ADM.LICENSE_H1(ID,
                           REF_CODE,
                           QUANTITY,
                           TARGET_TYPE,
                           ALL_TARGETS,
                           ALL_USERS,
                           PLICENSE_ID,
                           CUSTOMER_ID,
                           START_TIME,
                           START_ACTION,
                           END_TIME,
                           END_ACTION) select LH.ID,
                                              PH.REF_CODE,
                                              case
                                                when PH.CAPACITY_TYPE=3 then LH.QUANTITY*100
                                                when PH.CAPACITY_TYPE=2 then LH.QUANTITY*100
                                                else LH.QUANTITY
                                              end,
                                              LH.TARGET_TYPE,
                                              0,
                                              1,
                                              PH.ID,
                                              LH.CUSTOMER_ID,
                                              LH.START_TIME,
                                              'I',
                                              LH.END_TIME,
                                              case
                                                when LH.END_TIME = '9999-12-31-00.00.00.000000' then ''
                                                else 'U'
                                              end
                                       from ADM.LICENSE_H LH, ADM.PLICENSE_H PH
                                       where LH.ID = PH.ID and
                                             LH.START_TIME = PH.START_TIME and
                                             LH.END_TIME   = PH.END_TIME and
                                             LH.END_TIME > CURRENT TIMESTAMP - 3 MONTH;

-- change 'I' in 'U' as start_action whenever necessary (another row exists)
update ADM.LICENSE_H1 LH set START_ACTION='U' where START_TIME <> (select min(START_TIME)
                                                                   from ADM.LICENSE_H1
                                                                   where ID = LH.ID)
                                                and START_ACTION<>'U';
-- change 'U' in 'D' as end_action whenever necessary (no more rows exist)
update ADM.LICENSE_H1 LH set END_ACTION='D' where END_ACTION='U' and
                                                  END_TIME = (select max(END_TIME)
                                                              from ADM.LICENSE_H1
                                                              where ID = LH.ID);

-- all targets/all users setting
update ADM.LICENSE_H1 as LH set ALL_TARGETS = case
                                               when LH.TARGET_TYPE = 1 then 1
                                               else 0
                                              end;
-- see users relationship situation at historical start time
update ADM.LICENSE_H1 as LH set ALL_USERS = coalesce ((select 0
                                                       from SYSIBM.SYSDUMMY1
                                                       where exists(select LICENSE_ID
                                                                    from ADM.LIC_USER_HREL LUH
                                                                    where LH.ID = LUH.LICENSE_ID and
                                                                          LH.START_TIME >= LUH.START_TIME and
                                                                          LH.END_TIME >= LUH.END_TIME )), 1);

--table substitution
drop table ADM.LICENSE_H;
create table ADM.LICENSE_H
(
    ID                  bigint             not null,
    REF_CODE            char(25)           not null,
    QUANTITY            integer            not null,
    TARGET_TYPE         integer            not null,
    ALL_TARGETS         smallint           not null,
    ALL_USERS           smallint           not null,
    PLICENSE_ID         bigint             not null,
    CUSTOMER_ID         bigint             not null,
    START_TIME          timestamp          not null,
    START_ACTION        char(1)            not null,
    END_TIME            timestamp          not null,
    END_ACTION          char(1)            not null
);
insert into ADM.LICENSE_H select * from ADM.LICENSE_H1;
drop table ADM.LICENSE_H1;

create index ADM.LICENSE_H_I1 on ADM.LICENSE_H
(
    ID
);

-------------------------------------------------------------------------------
-- ADM.MODULE table moves to SWCAT schema;
-------------------------------------------------------------------------------
-- new table and filling
create table SWCAT.MODULE
(
    ID                  bigint             not null,
    NAME                varchar(254)       not null,
    SIZE_               bigint             not null,
    OS_NAME             varchar(12)        not null,
    VALUE               varchar(254),
    TYPE                integer            not null  default 0,
    SCOPE               smallint           not null  default 0,
    ENABLED             smallint           not null  default 1,
    SWARE_DESC          varchar(240),
    SWARE_VERS          varchar(64),
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

alter table SWCAT.MODULE add constraint MODULE_PK primary key
(
    ID
);

create unique index SWCAT.MODULE_UI1 on SWCAT.MODULE
(
    NAME,
    SIZE_,
    OS_NAME,
    VALUE
);

-- type 0, scope any, enabled 1
insert into SWCAT.MODULE (ID,
                          NAME,
                          SIZE_,
                          OS_NAME,
                          TYPE,
                          SCOPE,
                          ENABLED,
                          LAST_MODIFIED) select ID,
                                                NAME,
                                                SIZE,
                                                OS_NAME,
                                                0,
                                                0,
                                                1,
                                                LAST_MODIFIED
                                         from ADM.MODULE;

--old table dropped and new synonym
drop table ADM.MODULE;
create synonym ADM.MODULE for SWCAT.MODULE;

--update timestamps for modified
update SWCAT.MODULE
set LAST_MODIFIED = CURRENT TIMESTAMP
where ID in (select MODULE_ID
             from SWCAT.COMP_MOD_REL
             where COMPONENT_ID in (select ID
                                    from SWCAT.COMPONENT
                                    where LEVEL_ = 10));

--clean relationships for deleted products
delete from SWCAT.COMP_MOD_REL
where COMPONENT_ID in (select ID
                       from SWCAT.COMPONENT
                       where LEVEL_ = 10);

-------------------------------------------------------------------------------
-- ADM.NODE table dropping and re-creating:
-------------------------------------------------------------------------------
--reset EXT_ID
update ADM.NODE as ND
set EXT_ID = rtrim('TLM_' concat
                   (select C.VALUE from ADM.CONTROL C where NAME = 'ADMIN_ID') concat
                   '_' concat
                   char(ND.ID));

-- temporary table and filling
create table ADM.NODE1
(
    ID                  bigint             not null,
    TAG                 varchar(120)       not null,
    PLATFORM            varchar(20),
    NAME                varchar(192),
    HASH                bigint,
    CAPACITY            integer            not null  default 0,
    OOCOD               smallint           not null  default 0,
    LOCATION            varchar(240),
    DESCRIPTION         varchar(240),
    PLUGIN_TIME         timestamp          not null  default CURRENT TIMESTAMP,
    EXT_ID              varchar(80),
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

-- hash 0, platform appended in description
insert into ADM.NODE1(ID,
                      TAG,
                      HASH,
                      LOCATION,
                      DESCRIPTION,
                      PLUGIN_TIME,
                      EXT_ID,
                      CUSTOMER_ID,
                      LAST_MODIFIED) select ID,
                                            TAG,
                                            0,
                                            LOCATION,
                                            case when DESCRIPTION is null and PLATFORM is not null then 'Platform: ' concat PLATFORM
                                                 when DESCRIPTION is not null and PLATFORM is null then DESCRIPTION
                                                 when DESCRIPTION is not null and PLATFORM is not null then DESCRIPTION concat ' Platform: ' concat PLATFORM
                                                 else null
                                            end,
                                            LAST_MODIFIED,
                                            EXT_ID,
                                            CUSTOMER_ID,
                                            LAST_MODIFIED
                                     from ADM.NODE;

--table substitution
drop table ADM.NODE;
create table ADM.NODE
(
    ID                  bigint             not null,
    TAG                 varchar(120)       not null,
    PLATFORM            varchar(20),
    NAME                varchar(192),
    HASH                bigint,
    CAPACITY            integer            not null  default 0,
    OOCOD               smallint           not null  default 0,
    LOCATION            varchar(240),
    DESCRIPTION         varchar(240),
    PLUGIN_TIME         timestamp          not null  default CURRENT TIMESTAMP,
    EXT_ID              varchar(80),
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);
insert into ADM.NODE select * from ADM.NODE1;
drop table ADM.NODE1;

--indexes
alter table ADM.NODE add constraint NODE_PK primary key
(
    ID
);

create unique index ADM.NODE_UI1 on ADM.NODE
(
    EXT_ID,
    CUSTOMER_ID
);

create index ADM.NODE_I1 on ADM.NODE
(
    TAG
);

create index ADM.NODE_I2 on ADM.NODE
(
    NAME
);

-------------------------------------------------------------------------------
-- ADM.NODE_H new historical table
-------------------------------------------------------------------------------
create table ADM.NODE_H
(
    ID                  bigint             not null,
    TAG                 varchar(120)       not null,
    PLATFORM            varchar(20),
    NAME                varchar(192),
    HASH                bigint,
    CAPACITY            integer            not null,
    OOCOD               smallint           not null,
    PLUGIN_TIME         timestamp          not null,
    CUSTOMER_ID         bigint             not null,
    START_TIME          timestamp          not null,
    START_ACTION        char(1)            not null,
    END_TIME            timestamp          not null,
    END_ACTION          char(1)            not null
);

-- all of the present row are represented as just inserted
insert into ADM.NODE_H(ID,
                       TAG,
                       HASH,
                       CAPACITY,
                       OOCOD,
                       PLUGIN_TIME,
                       CUSTOMER_ID,
                       START_TIME,
                       START_ACTION,
                       END_TIME,
                       END_ACTION) select ID,
                                          TAG,
                                          0,
                                          CAPACITY,
                                          OOCOD,
                                          PLUGIN_TIME,
                                          CUSTOMER_ID,
                                          LAST_MODIFIED,
                                          'I',
                                          '9999-12-31-00.00.00.000000',
                                          '-'
                                    from  ADM.NODE;

create index ADM.NODE_H_I1 on ADM.NODE_H
(
    ID
);

create index ADM.NODE_H_I2 on ADM.NODE_H
(
    OOCOD,
    ID,
    PLUGIN_TIME
);

-------------------------------------------------------------------------------
-- ADM.OID table dropping and re-creating:
-------------------------------------------------------------------------------
-- swcat oid new table
create table SWCAT.OID
(
    LAST_ID             bigint             not null,
    TABLE_NAME          varchar(40)        not null,
    BLOCK_SIZE          integer            not null
);
--indexes
alter table SWCAT.OID add constraint OID_PK primary key
(
    TABLE_NAME
);

-- catalog entries - block size must be accorded to the swcat definition
insert into SWCAT.OID select LAST_ID, 'swcat.component', 3 from ADM.OID where TABLE_NAME='adm.component';
insert into SWCAT.OID select LAST_ID, 'swcat.module', 1 from ADM.OID where TABLE_NAME='adm.module';

-- delete old entries
delete from ADM.OID where TABLE_NAME in ('adm.vendor',
                                         'adm.component',
                                         'adm.module',
                                         'adm.command',
                                         'adm.usage',
                                         'adm.usage_h');




-- temporary table and filling
create table ADM.OID1
(
    LAST_ID             bigint             not null,
    TABLE_NAME          varchar(40)        not null,
    BLOCK_SIZE          integer            not null
);

insert into ADM.OID1(LAST_ID,
                     TABLE_NAME,
                     BLOCK_SIZE) select LAST_ID,
                                        TABLE_NAME,
                                        0
                                     from ADM.OID;

-- new entries
insert into ADM.OID1 select coalesce (max(ID),0), 'adm.agent_inv',        100 from ADM.AGENT_INV;
insert into ADM.OID1 select coalesce (max(ID),0), 'adm.contract',          10 from ADM.CONTRACT;
insert into ADM.OID1 select coalesce (max(ID),0), 'adm.plicense',          10 from ADM.PLICENSE;
insert into ADM.OID1 select coalesce (max(ID),0), 'adm.inv_h_lic',         10 from ADM.INV_H_LIC;
insert into ADM.OID1 select coalesce (max(ID),0), 'adm.inv_h_plic',        10 from ADM.INV_H_PLIC;
insert into ADM.OID1 select coalesce (max(ID),0), 'adm.inv_h_lic_comp',    10 from ADM.INV_H_LIC_COMP;
insert into ADM.OID1 select coalesce (max(ID),0), 'adm.inv_h_plic_comp',   10 from ADM.INV_H_PLIC_COMP;
insert into ADM.OID1 select coalesce (max(ID),0), 'adm.inv_h_comp',        10 from ADM.INV_H_COMP;

-- update BLOCK_SIZE field for old entries
update ADM.OID1 set BLOCK_SIZE = 1 where TABLE_NAME in ('adm.administrator',
                                                        'adm.customer',
                                                        'adm.server'
                                                       );
update ADM.OID1 set BLOCK_SIZE = 10 where TABLE_NAME in ('adm.division',
                                                         'adm.enduser',
                                                         'adm.entitlement',
                                                         'adm.license',
                                                         'adm.node',
                                                         'adm.profile'
                                                         );
update ADM.OID1 set BLOCK_SIZE = 100 where TABLE_NAME in ('adm.agent',
                                                          'adm.unknown');

--table substitution
drop table ADM.OID;
create table ADM.OID
(
    LAST_ID             bigint             not null,
    TABLE_NAME          varchar(40)        not null,
    BLOCK_SIZE          integer            not null
);
insert into ADM.OID select * from ADM.OID1;
drop table ADM.OID1;

--indexes
alter table ADM.OID add constraint OID_PK primary key
(
    TABLE_NAME
);


-------------------------------------------------------------------------------
-- ADM.OPT_FIELD new empty table
-------------------------------------------------------------------------------
create table ADM.OPT_FIELD
(
    OPT_FIELD_ID        bigint             not null,
    TABLE_RECORD_ID     bigint             not null,
    VALUE               varchar(600)       not null
);

alter table ADM.OPT_FIELD add constraint OPT_FIELD_PK primary key
(
    OPT_FIELD_ID,
    TABLE_RECORD_ID
);

-------------------------------------------------------------------------------
-- ADM.OPT_FIELD_DEF to be filled with dat
-------------------------------------------------------------------------------
create table ADM.OPT_FIELD_DEF
(
    ID                  bigint             not null,
    TABLE_NAME          varchar(20)        not null,
    NAME                varchar(20)        not null,
    TYPE                char(1)            not null
);

alter table ADM.OPT_FIELD_DEF add constraint OPT_FIELD_DEF_PK primary key
(
    ID
);

create unique index ADM.OPT_FIELD_DEF_UI1 on ADM.OPT_FIELD_DEF
(
    TABLE_NAME,
    NAME
);

import from ./opt_field_def.dat of del commitcount 5000 restartcount 1 insert into ADM.OPT_FIELD_DEF (ID, TABLE_NAME, NAME, TYPE);

-------------------------------------------------------------------------------
-- ADM.PROFILE indexes and content management
-------------------------------------------------------------------------------
-- index renamed
drop index ADM.PROFILE_UI;
create unique index ADM.PROFILE_UI1 on ADM.PROFILE
(
    DESCRIPTION
);

-- old two news profiles mapping (for licensing and reporting)
update ADM.ADMIN_CUST_REL AC set PROFILE_ID = case
                                               when AC.PROFILE_ID = 3 then 7
                                               when AC.PROFILE_ID = 4 then 6
                                               else AC.PROFILE_ID
                                              end;

-- replace content
delete from ADM.PROFILE;
insert into ADM.PROFILE (ID, NAME, DESCRIPTION) values (1, 'tlmroot', 'Root user profile');
insert into ADM.PROFILE (ID, NAME, DESCRIPTION) values (2, 'Administration', 'Administrator user profile');
insert into ADM.PROFILE (ID, NAME, DESCRIPTION) values (3, 'ProcurementMan', 'Procurement Manager user profile');
insert into ADM.PROFILE (ID, NAME, DESCRIPTION) values (4, 'SoftwareResource', 'Software Resources Manager user profile');
insert into ADM.PROFILE (ID, NAME, DESCRIPTION) values (5, 'LicenseAdmin', 'License Administrator user profile');
insert into ADM.PROFILE (ID, NAME, DESCRIPTION) values (6, 'SystemResource', 'System Resources Manager user profile');
insert into ADM.PROFILE (ID, NAME, DESCRIPTION) values (7, 'ProcurementLicensing', 'Procurement & Licensing user profile');

-------------------------------------------------------------------------------
-- ADM.PROFILE_ACTION indexes and content management
-------------------------------------------------------------------------------
-- primary key renamed implies table drop and recreation
drop table ADM.PROFILE_ACTION;
create table ADM.PROFILE_ACTION
(
    PROFILE_ID          bigint             not null,
    ACTION_KEY          varchar(40)        not null,
    ACTION_VALUE        varchar(20)        not null
);

alter table ADM.PROFILE_ACTION add constraint PROFILE_ACTION_PK primary key
(
    PROFILE_ID,
    ACTION_KEY
);


-- administrator cannot manage customers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_c_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_c_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_c_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_c_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_c_u_02', 'false');
-- administrator cannot work with accounts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_a_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_a_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_m_a_u', 'false');
-- administrator cannot define profiles
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_d_p_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_d_p_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_d_p_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_d_p_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_d_p_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_d_p_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (2, 'ad_d_p_u', 'false');

-- procurement manager cannot distribute licenses
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_04', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_s_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_u_s_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_u_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_u_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_m', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_m_dt_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_m_dt_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_b_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_b_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_b_c_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_c_t_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_c_t_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_c_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_cnt_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_cnt_04', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_m_l', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_d_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_d_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_f_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_l_f_u', 'false');
-- procurement manager cannot define enforcement
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_e_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_e_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_e_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_e_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_e_cnt', 'false');
-- procurement manager cannot schedule installs scan
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_s_i_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_s_i_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_s_i_s_s', 'false');
-- procurement  manager cannot manage divisions
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_d_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_d_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_d_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_d_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_d_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_d_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_d_v_a', 'false');
-- procurement  manager cannot manage nodes
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_n_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_n_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_n_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_n_s', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_n_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_n_v_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_n_cr_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_n_cr_02', 'false');
-- procurement  manager cannot manage users
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_u_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_u_03', 'false');
-- procurement  manager cannot manage servers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_v_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_m_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_s_s', 'false');
-- procurement manager cannot view agents
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_v_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_v_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_v_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_v_a_dt', 'false');
-- procurement manager cannot manage customers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_c_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_c_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_c_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_c_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_c_u_02', 'false');
-- procurement manager cannot work with accounts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_a_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_a_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_m_a_u', 'false');
-- procurement manager cannot define profiles
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_p_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_p_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_p_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_p_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_p_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_p_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_d_p_u', 'false');
-- procurement manager cannot export ibm usage
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (3, 'ad_e_i_u_01', 'false');

-- software resource manager cannot procure licenses
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_ch_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_c_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_se_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_se_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_se_c_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_br_co', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_b_se_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_b_se_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_p_l_cnt', 'false');
-- software resource manager cannot manage contracts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_ct_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_ct_cr', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_ct_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_ct_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_ct_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_ct_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_ct_u_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_ct_v_l', 'false');
-- software resource manager cannot distribute licenses
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_04', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_s_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_u_s_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_u_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_u_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_m', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_m_dt_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_m_dt_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_b_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_b_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_b_c_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_c_t_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_c_t_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_c_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_cnt_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_cnt_04', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_m_l', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_d_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_d_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_f_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_l_f_u', 'false');
-- software resource manager cannot define enforcement
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_e_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_e_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_e_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_e_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_e_cnt', 'false');
-- software resource manager cannot schedule installs scan
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_s_i_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_s_i_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_s_i_s_s', 'false');
-- software resource manager cannot manage divisions
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_d_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_d_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_d_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_d_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_d_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_d_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_d_v_a', 'false');
-- software resource manager cannot manage nodes
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_n_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_n_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_n_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_n_s', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_n_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_n_v_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_n_cr_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_n_cr_02', 'false');
-- software resource manager cannot manage users
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_u_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_u_03', 'false');
-- software resource manager cannot manage servers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_v_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_m_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_s_s', 'false');
-- software resource manager cannot view agents
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_v_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_v_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_v_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_v_a_dt', 'false');
-- software resources manager cannot manage customers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_c_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_c_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_c_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_c_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_c_u_02', 'false');
-- software resources manager cannot work with accounts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_a_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_a_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_m_a_u', 'false');
-- software resource manager cannot define profiles
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_p_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_p_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_p_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_p_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_p_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_p_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_p_u', 'false');
-- software resource manager cannot define custom fields
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_c_f_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_c_f_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_c_f_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_d_c_f_04', 'false');
-- software resource manager cannot export ibm usage
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (4, 'ad_e_i_u_01', 'false');

-- license administrator cannot procure licenses
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_ch_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_c_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_se_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_se_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_se_c_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_br_co', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_b_se_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_b_se_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_p_l_cnt', 'false');
-- license administrator cannot manage contracts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_ct_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_ct_cr', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_ct_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_ct_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_ct_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_ct_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_ct_u_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_ct_v_l', 'false');
-- license administrator cannot schedule installs scan
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_s_i_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_s_i_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_s_i_s_s', 'false');
-- license administrator cannot manage divisions
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_d_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_d_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_d_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_d_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_d_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_d_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_d_v_a', 'false');
-- license administrator cannot manage nodes
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_n_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_n_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_n_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_n_s', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_n_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_n_v_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_n_cr_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_n_cr_02', 'false');
-- license administrator cannot manage users
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_u_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_u_03', 'false');
-- license administrator cannot manage servers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_v_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_m_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_s_s', 'false');
-- license administrator cannot view agents
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_v_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_v_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_v_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_v_a_dt', 'false');
-- license administrator cannot manage customers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_c_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_c_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_c_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_c_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_c_u_02', 'false');
-- license administrator cannot work with accounts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_a_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_a_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_m_a_u', 'false');
-- license administrator cannot define profiles
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_p_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_p_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_p_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_p_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_p_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_p_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_p_u', 'false');
-- license administrator cannot define custom fields
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_c_f_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_c_f_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_c_f_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (5, 'ad_d_c_f_04', 'false');

-- System Resource manager cannot view installs snapshot
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_s_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_s_04', 'false');
-- System Resource manager cannot view installs history
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_h_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_h_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_h_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_h_04', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_h_05', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_i_h_06', 'false');
-- System Resource manager cannot view usage snapshot
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_s_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_s_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_s_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_s_p_01', 'false');
-- System Resource manager cannot view usage trend
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_t_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_t_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_t_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_t_04', 'false');
-- System Resource manager cannot view usage level
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_l_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_v_u_l_04', 'false');
-- System Resource manager cannot view available licenses
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_a_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_a_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_a_l_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_a_l_r', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_a_l_d', 'false');
-- System Resource manager cannot produce license compliance
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_l_c_01', 'false');
-- System Resource manager cannot procure licenses
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_ch_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_c_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_se_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_se_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_se_c_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_br_co', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_b_se_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_b_se_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_cnt', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_p_l_c_f', 'false');
-- System Resource manager cannot manage contracts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_cr', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_u_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_u_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_ct_v_l', 'false');
-- System Resource manager cannot distribute licenses
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_04', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_s_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_u_s_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_u_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_u_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_m', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_m_dt_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_m_dt_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_b_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_b_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_b_c_f', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_c_t_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_c_t_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_c_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_cnt_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_cnt_04', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_m_l', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_d_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_d_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_f_t', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_l_f_u', 'false');
-- System Resource manager cannot define enforcement
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_e_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_e_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_e_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_e_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_e_cnt', 'false');
-- System Resource manager cannot manage customers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_c_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_c_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_c_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_c_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_c_u_02', 'false');
-- System Resource manager cannot work with accounts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_a_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_a_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_m_a_u', 'false');
-- System Resource manager cannot define profiles
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_p_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_p_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_p_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_p_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_p_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_p_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_p_u', 'false');
-- System Resource manager cannot define custom fields
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_c_f_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_c_f_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_c_f_03', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_d_c_f_04', 'false');
-- System Resource manager cannot export ibm usage
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (6, 'ad_e_i_u_01', 'false');

-- Procurement Licensing administrator cannot manage divisions
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_d_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_d_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_d_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_d_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_d_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_d_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_d_v_a', 'false');
-- Procurement Licensing administrator cannot manage nodes
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_n_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_n_ch_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_n_ch_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_n_s', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_n_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_n_v_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_n_cr_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_n_cr_02', 'false');
-- Procurement Licensing administrator cannot manage users
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_u_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_u_03', 'false');
-- Procurement Licensing administrator cannot manage servers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_u', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_v_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_m_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_s_s', 'false');
-- Procurement Licensing administrator cannot view agents
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_v_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_v_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_v_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_v_a_dt', 'false');
-- Procurement Licensing administrator cannot manage customers
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_c_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_c_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_c_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_c_u_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_c_u_02', 'false');
-- Procurement Licensing administrator cannot work with accounts
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_a_c_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_a_c_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_a_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_a_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_a_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_m_a_u', 'false');
-- Procurement Licensing administrator cannot define profiles
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_d_p_01', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_d_p_02', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_d_p_c', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_d_p_ch', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_d_p_a', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_d_p_d', 'false');
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_d_p_u', 'false');
-- Procurement Licensing administrator cannot export ibm usage
insert into ADM.PROFILE_ACTION (PROFILE_ID, ACTION_KEY, ACTION_VALUE) values (7, 'ad_e_i_u_01', 'false');

-------------------------------------------------------------------------------
-- ADM.SERVER table dropping and re-creating:
-------------------------------------------------------------------------------
-- temporary table and filling
create table ADM.SERVER1
(
    ID                  bigint             not null,
    NAME                varchar(180)       not null,
    ADDRESS             varchar(180)       not null,
    PASSWORD            varchar(40)        not null,
    VERSION             varchar(10),
    PORT_NUMBER         integer            not null  default 80,
    SSL_PORT_NUMBER     integer            not null  default 443,
    SSL_ENABLED         smallint           not null  default 0,
    FORCE_SERVICE       char(3)            not null  default 'YNN',
    DOWNLOAD_PERIOD     bigint             not null  default 0,
    UPLOAD_PERIOD       bigint             not null  default 0,
    UPDATE_PERIOD       bigint             not null  default 0,
    WARNING_TIME        timestamp          not null  default CURRENT TIMESTAMP,
    LOCATION            varchar(120),
    OUTAGE_STATUS       smallint           not null  default 0,
    BACKUP_SERVER_ID    bigint,
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

-- version is null
insert into ADM.SERVER1(ID,
                        NAME,
                        ADDRESS,
                        PASSWORD,
                        PORT_NUMBER,
                        FORCE_SERVICE,
                        DOWNLOAD_PERIOD,
                        UPLOAD_PERIOD,
                        UPDATE_PERIOD,
                        CUSTOMER_ID,
                        LAST_MODIFIED) select ID,
                                              NAME,
                                              ADDRESS,
                                              PASSWORD,
                                              PORT_NUMBER,
                                              FORCE_SERVICE,
                                              DOWNLOAD_PERIOD,
                                              UPLOAD_PERIOD,
                                              UPDATE_PERIOD,
                                              CUSTOMER_ID,
                                              LAST_MODIFIED
                                        from ADM.SERVER;

--table substitution
drop table ADM.SERVER;
create table ADM.SERVER
(
    ID                  bigint             not null,
    NAME                varchar(180)       not null,
    ADDRESS             varchar(180)       not null,
    PASSWORD            varchar(40)        not null,
    VERSION             varchar(10),
    PORT_NUMBER         integer            not null  default 80,
    SSL_PORT_NUMBER     integer            not null  default 443,
    SSL_ENABLED         smallint           not null  default 0,
    FORCE_SERVICE       char(3)            not null  default 'YNN',
    DOWNLOAD_PERIOD     bigint             not null  default 0,
    UPLOAD_PERIOD       bigint             not null  default 0,
    UPDATE_PERIOD       bigint             not null  default 0,
    WARNING_TIME        timestamp          not null  default CURRENT TIMESTAMP,
    LOCATION            varchar(120),
    OUTAGE_STATUS       smallint           not null  default 0,
    BACKUP_SERVER_ID    bigint,
    CUSTOMER_ID         bigint             not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);
insert into ADM.SERVER select * from ADM.SERVER1;
drop table ADM.SERVER1;

--indexes

alter table ADM.SERVER add constraint SERVER_PK primary key
(
    ID
);

create unique index ADM.SERVER_UI1 on ADM.SERVER
(
    CUSTOMER_ID,
    NAME
);

create unique index ADM.SERVER_UI2 on ADM.SERVER
(
    CUSTOMER_ID,
    ADDRESS
);

-------------------------------------------------------------------------------
-- ADM.SERVER_H table altering..
-------------------------------------------------------------------------------
delete from ADM.SERVER_H where end_time < CURRENT TIMESTAMP - 3 MONTH;
create index ADM.SERVER_H_I1 on ADM.SERVER_H
(
    ID
);


-------------------------------------------------------------------------------
-- ADM.SERVICE table dropping and re-creating:
-------------------------------------------------------------------------------
create table ADM.SERVICE1
(
    SERVICE_ID          integer            not null,
    SERVER_ID           bigint             not null,
    INSERTED            timestamp          not null,
    FORCE_CHECK_TIME    timestamp,
    DESCRIPTION         varchar(80)
);

insert into ADM.SERVICE1 (SERVICE_ID,
                          SERVER_ID,
                          INSERTED,
                          DESCRIPTION) select SERVICE_ID,
                                              SERVER_ID,
                                              INSERTED,
                                              DESCRIPTION
                                         from ADM.SERVICE
                                        where INSERTED > CURRENT TIMESTAMP - 3 MONTH;

drop table ADM.SERVICE;

create table ADM.SERVICE
(
    SERVICE_ID          integer            not null,
    SERVER_ID           bigint             not null,
    INSERTED            timestamp          not null,
    FORCE_CHECK_TIME    timestamp,
    DESCRIPTION         varchar(80)
);

insert into ADM.SERVICE select * from ADM.SERVICE1;
drop table ADM.SERVICE1;

--indexes
alter table ADM.SERVICE add constraint SERVICE_PK primary key
(
    SERVICE_ID,
    SERVER_ID,
    INSERTED
);

-------------------------------------------------------------------------------
-- ADM.UNKNOWN table moves to SWCAT schema;
-------------------------------------------------------------------------------
-- new table and filling
create table SWCAT.UNKNOWN
(
    ID                  bigint             not null,
    NAME                varchar(254)       not null,
    SIZE_               bigint             not null,
    TYPE                integer            not null  default 0,
    CHECKSUM            bigint             not null,
    OS_NAME             varchar(12)        not null,
    PATH                varchar(400),
    DESCRIPTION         varchar(80),
    VERSION             varchar(40),
    TEXT1               varchar(80),
    TEXT2               varchar(80),
    ENABLED             smallint           not null  default 1,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

alter table SWCAT.UNKNOWN add constraint UNKNOWN_PK primary key
(
    ID
);

create unique index SWCAT.UNKNOWN_UI1 on SWCAT.UNKNOWN
(
    NAME,
    SIZE_,
    OS_NAME
);

insert into SWCAT.UNKNOWN (ID,
                           NAME,
                           SIZE_,
                           CHECKSUM,
                           OS_NAME,
                           PATH,
                           DESCRIPTION,
                           VERSION,
                           TEXT1,
                           TEXT2,
                           LAST_MODIFIED) select ID,
                                                 NAME,
                                                 SIZE,
                                                 CHECKSUM,
                                                 OS_NAME,
                                                 PATH,
                                                 DESCRIPTION,
                                                 VERSION,
                                                 TEXT1,
                                                 TEXT2,
                                                 LAST_MODIFIED
                                          from ADM.UNKNOWN;

--old table dropped and new synonym
drop table ADM.UNKNOWN;
create synonym ADM.UNKNOWN for SWCAT.UNKNOWN;

-------------------------------------------------------------------------------
-- ADM.USAGE table moves to USAGE_COMP, USAGE_LIC, USAGE_COMP_USER;
-------------------------------------------------------------------------------
--agent_id null rows must be updated
update ADM.USAGE set AGENT_ID=0 where AGENT_ID is null;

--usage comp creation and filling
create table ADM.USAGE_COMP
(
    ID                  bigint             not null,
    COMPONENT_ID        bigint             not null,
    AGENT_ID            bigint             not null,
    DIVISION_ID         bigint             not null,
    CUSTOMER_ID         smallint           not null,
    START_TIME          timestamp          not null,
    END_TIME            timestamp          not null
);

alter table ADM.USAGE_COMP add constraint USAGE_COMP_PK primary key
(
    ID
);

create index ADM.USAGE_COMP_I1 on ADM.USAGE_COMP
(
    COMPONENT_ID
);

--export usage for usage_comp table and import it null division_id/component_id rows are skipped
export to usage_comp_111_21.dat of del select (SERVER_ID * 281474976710656) + TRANSACTION_ID,
                                              COMPONENT_ID,
                                              AGENT_ID,
                                              DIVISION_ID,
                                              CUSTOMER_ID,
                                              START_TIME,
                                              END_TIME
                                        from ADM.USAGE
                                        where COMPONENT_ID is not null
                                          and DIVISION_ID is not null
                                          and END_TIME > CURRENT TIMESTAMP - 3 MONTH;

load from usage_comp_111_21.dat of del insert into ADM.USAGE_COMP;

--usage comp user creation and filling
create table ADM.USAGE_COMP_USER
(
    USAGE_COMP_ID       bigint             not null,
    USER                varchar(60),
    GROUP               varchar(60)
);

alter table ADM.USAGE_COMP_USER add constraint USAGE_COMP_USER_PK primary key
(
    USAGE_COMP_ID
);


-- usage_comp_id it's the reference to usage comp and now it's the same as for usage
-- (for the way usage_comp was built)
-- export usage for usage_comp_user table, avoid privacy rows
export to usage_comp_user_111_21.dat of del select (SERVER_ID * 281474976710656) + TRANSACTION_ID,
                                                   LOGON_NAME,
                                                   GROUP_NAME
                                            from ADM.USAGE
                                            where (LOGON_NAME <> '******' or
                                                   GROUP_NAME <> '******')
                                              and END_TIME > CURRENT TIMESTAMP - 3 MONTH;

load from usage_comp_user_111_21.dat of del insert into ADM.USAGE_COMP_USER;

-- usage lic creation and filling
create table ADM.USAGE_LIC
(
    USAGE_COMP_ID       bigint             not null,
    LICENSE_ID          bigint             not null,
    COMPONENT_ID        bigint             not null,
    QUANTITY            integer            not null,
    POOL_HASH           bigint             not null,
    POOL_CAPACITY       integer            not null,
    LPAR_HASH           bigint             not null,
    LPAR_CAPACITY       integer            not null,
    NODE_HASH           bigint             not null,
    NODE_CAPACITY       integer            not null,
    START_TIME          timestamp          not null,
    END_TIME            timestamp          not null
);

alter table ADM.USAGE_LIC add constraint USAGE_LIC_PK primary key
(
    USAGE_COMP_ID,
    START_TIME
);

create index ADM.USAGE_LIC_I1 on ADM.USAGE_LIC
(
    LICENSE_ID,
    COMPONENT_ID
);

-- usage_comp_id it's the reference to usage comp and now it's the same as for usage
-- (for the way usage_comp was built)
-- export usage for usage_lic table, avoid privacy rows
export to usage_lic_111_21.dat of del select (SERVER_ID * 281474976710656) + TRANSACTION_ID,
                                             LICENSE_ID,
                                             COMPONENT_ID,
                                             QUANTITY_GRANTED,
                                             0,
                                             0,
                                             0,
                                             0,
                                             0,
                                             0,
                                             START_TIME,
                                             END_TIME
                                       from ADM.USAGE
                                       where COMPONENT_ID is not null
                                         and END_TIME > CURRENT TIMESTAMP - 3 MONTH;

load from usage_lic_111_21.dat of del insert into ADM.USAGE_LIC;

-- now usage can be dropped
drop table ADM.USAGE;

-------------------------------------------------------------------------------
-- ADM.USAGE_H_COMP new empty table
-------------------------------------------------------------------------------
create table ADM.USAGE_H_COMP
(
    ID                  bigint             not null,
    CUSTOMER_ID         bigint             not null,
    COMPONENT_ID        bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null,
    HWM_TIME            time               not null,
    AWM                 float              not null,
    UNLICENSED_HWM      integer            not null,
    RIF_HWM             integer            not null
);

alter table ADM.USAGE_H_COMP add constraint USAGE_H_COMP_PK primary key
(
    CUSTOMER_ID,
    COMPONENT_ID,
    DATE_USAGE
);

create unique index ADM.USAGE_H_COMP_UI1 on ADM.USAGE_H_COMP
(
    ID
);

-- oid table
insert into ADM.OID select coalesce (max(ID),0), 'adm.usage_h_comp',      10 from ADM.USAGE_H_COMP;

-------------------------------------------------------------------------------
-- ADM.USAGE_H_DIV new empty table
-------------------------------------------------------------------------------
create table ADM.USAGE_H_DIV
(
    ID                  bigint             not null,
    DIVISION_ID         bigint             not null,
    COMPONENT_ID        bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null,
    HWM_TIME            time               not null,
    AWM                 float              not null
);

alter table ADM.USAGE_H_DIV add constraint USAGE_H_DIV_PK primary key
(
    DIVISION_ID,
    COMPONENT_ID,
    DATE_USAGE
);

create unique index ADM.USAGE_H_DIV_UI1 on ADM.USAGE_H_DIV
(
    ID
);

-- oid table
insert into ADM.OID select coalesce (max(ID),0), 'adm.usage_h_div',       10 from ADM.USAGE_H_DIV;

-------------------------------------------------------------------------------
-- ADM.USAGE_H_LIC new empty table
-------------------------------------------------------------------------------
create table ADM.USAGE_H_LIC
(
    ID                  bigint             not null,
    LICENSE_ID          bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null,
    HWM_TIME            time               not null,
    AWM                 float              not null
);

alter table ADM.USAGE_H_LIC add constraint USAGE_H_LIC_PK primary key
(
    LICENSE_ID,
    DATE_USAGE
);

create unique index ADM.USAGE_H_LIC_UI1 on ADM.USAGE_H_LIC
(
    ID
);

-- oid table
insert into ADM.OID select coalesce (max(ID),0), 'adm.usage_h_lic',       10 from ADM.USAGE_H_LIC;

-------------------------------------------------------------------------------
-- ADM.USAGE_H_LIC_COMP new empty table
-------------------------------------------------------------------------------
create table ADM.USAGE_H_LIC_COMP
(
    ID                  bigint             not null,
    LICENSE_ID          bigint             not null,
    COMPONENT_ID        bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null,
    HWM_TIME            time               not null
);

alter table ADM.USAGE_H_LIC_COMP add constraint USAGE_H_LI_CMP_PK primary key
(
    LICENSE_ID,
    COMPONENT_ID,
    DATE_USAGE
);

-- oid table
insert into ADM.OID select coalesce (max(ID),0), 'adm.usage_h_lic_comp',  10 from ADM.USAGE_H_LIC_COMP;

-------------------------------------------------------------------------------
-- ADM.USAGE_H_OOCOD new empty table
-------------------------------------------------------------------------------
create table ADM.USAGE_H_OOCOD
(
    ID                  bigint             not null,
    NODE_ID             bigint             not null,
    CAPACITY            integer            not null,
    COMPONENT_ID        bigint             not null,
    PLICENSE_ID         bigint             not null,
    DATE_USAGE          date               not null
);

alter table ADM.USAGE_H_OOCOD add constraint USAGE_H_OOCOD_PK primary key
(
    NODE_ID,
    DATE_USAGE,
    COMPONENT_ID,
    PLICENSE_ID
);

create unique index ADM.USAGE_H_OOCOD_UI1 on ADM.USAGE_H_OOCOD
(
    ID
);

insert into ADM.OID select coalesce (max(ID),0), 'adm.usage_h_oocod',       10 from ADM.USAGE_H_OOCOD;

-------------------------------------------------------------------------------
-- ADM.USAGE_H_PLIC new empty table
-------------------------------------------------------------------------------
create table ADM.USAGE_H_PLIC
(
    ID                  bigint             not null,
    PLICENSE_ID         bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null,
    HWM_TIME            time               not null,
    AWM                 float              not null
);

alter table ADM.USAGE_H_PLIC add constraint USAGE_H_PLIC_PK primary key
(
    PLICENSE_ID,
    DATE_USAGE
);

-- oid table
insert into ADM.OID select coalesce (max(ID),0), 'adm.usage_h_plic',      10 from ADM.USAGE_H_PLIC;

-------------------------------------------------------------------------------
-- ADM.USAGE_H_PLIC_COMP new empty table
-------------------------------------------------------------------------------
create table ADM.USAGE_H_PLIC_COMP
(
    ID                  bigint             not null,
    PLICENSE_ID         bigint             not null,
    COMPONENT_ID        bigint             not null,
    DATE_USAGE          date               not null,
    HWM                 integer            not null,
    HWM_TIME            time               not null
);

alter table ADM.USAGE_H_PLIC_COMP add constraint USAGE_H_PL_CMP_PK primary key
(
    PLICENSE_ID,
    COMPONENT_ID,
    DATE_USAGE
);

-- oid table
insert into ADM.OID select coalesce (max(ID),0), 'adm.usage_h_plic_comp', 10 from ADM.USAGE_H_PLIC_COMP;

-------------------------------------------------------------------------------
-- ADM.USAGE_H table dropping
-------------------------------------------------------------------------------
drop table ADM.USAGE_H;

-------------------------------------------------------------------------------
-- ADM.VENDOR table moves to SWCAT schema;
-------------------------------------------------------------------------------
-- new table and filling
create table SWCAT.VENDOR
(
    ID                  bigint             not null,
    NAME                varchar(80)        not null,
    LAST_MODIFIED       timestamp          not null  default CURRENT TIMESTAMP
);

alter table SWCAT.VENDOR add constraint VENDOR_PK primary key
(
    ID
);

create unique index SWCAT.VENDOR_UI1 on SWCAT.VENDOR
(
    NAME
);

insert into SWCAT.VENDOR (ID,
                          NAME,
                          LAST_MODIFIED) select ID,
                                                NAME,
                                                LAST_MODIFIED
                                         from ADM.VENDOR;

--old table dropped and new synonym
drop table ADM.VENDOR;
create synonym ADM.VENDOR for SWCAT.VENDOR;


-------------------------------------------------------------------------------
-- Create comments
-------------------------------------------------------------------------------

comment on table  ADM.ADMIN_CUST_REL is
    'Maps the ADMINISTRATOR table to the CUSTOMER table (many-to-many).';
comment on column ADM.ADMIN_CUST_REL.ADMINISTRATOR_ID is
    'External key to ADMINISTRATOR table';
comment on column ADM.ADMIN_CUST_REL.CUSTOMER_ID is
    'External key to CUSTOMER table';
comment on column ADM.ADMIN_CUST_REL.PROFILE_ID is
    'Administrator profile (foreign key to PROFILE table)';
comment on column ADM.ADMIN_CUST_REL.HIDE_HOST_INV is
    'Enables/disables the visualization of the machine details on the GUI for privacy reasons (sw inventory)';
comment on column ADM.ADMIN_CUST_REL.HIDE_HOST is
    'Enables/disables the visualization of the machine details on the GUI for privacy reasons';
comment on column ADM.ADMIN_CUST_REL.HIDE_USER is
    'Enables/disables the visualization of the user details on the GUI for privacy reasons';
comment on column ADM.ADMIN_CUST_REL.HIDE_GROUP is
    'Enables/disables the visualization of the group details on the GUI for privacy reasons';

-------------------------------------------------------------------------------

comment on table  ADM.ADMINISTRATOR is
    'Stores details of administration server administrators.';
comment on column ADM.ADMINISTRATOR.LOGON_NAME is
    'User ID for logging on to Tivoli License Manager';
comment on column ADM.ADMINISTRATOR.FIRST_NAME is
    'First name of the administrator';
comment on column ADM.ADMINISTRATOR.MIDDLE_NAME is
    'Middle name or names of the administrator';
comment on column ADM.ADMINISTRATOR.LAST_NAME is
    'Surname of the administrator';
comment on column ADM.ADMINISTRATOR.PASSWORD is
    'Encrypted password of the administrator';
comment on column ADM.ADMINISTRATOR.EMAIL_ADDRESS is
    'E-mail address of the administrator';
comment on column ADM.ADMINISTRATOR.EVENT_NOTIFICATION is
    'E-mail event notification flag';
comment on column ADM.ADMINISTRATOR.PHONE is
    'Telephone number of the administrator';
comment on column ADM.ADMINISTRATOR.FAX is
    'Fax number of the administrator';
comment on column ADM.ADMINISTRATOR.EXT_ID is
    'Unique identifier for importing or exporting';

-------------------------------------------------------------------------------

comment on table  ADM.AGENT is
    'Stores details of installed Tivoli License Manager agents.';
comment on column ADM.AGENT.HOSTNAME is
    'System host name (e.g. omega.ibm.com)';
comment on column ADM.AGENT.IP_ADDRESS is
    'Network IP address';
comment on column ADM.AGENT.VERSION is
    'Version of the agent that is installed';
comment on column ADM.AGENT.OS_NAME is
    'Operating system name (Unix, Windows, OS/400)';
comment on column ADM.AGENT.OS_VERSION is
    'Operating system version (e.g. 2.1, NT4, 2000)';
comment on column ADM.AGENT.MEMORY is
    'Ram size in megabytes';
comment on column ADM.AGENT.DISKS is
    'Number of hard disk drives';
comment on column ADM.AGENT.STORAGE is
    'Internal use';
comment on column ADM.AGENT.PROCESSORS is
    'Number of processors installed on the computer';
comment on column ADM.AGENT.LPAR_NAME is
    'Logical partition name';
comment on column ADM.AGENT.LPAR_CAPACITY is
    'Logical partition processor capacity';
comment on column ADM.AGENT.POOL_NAME is
    'Shared pool name';
comment on column ADM.AGENT.POOL_CAPACITY is
    'Shared pool processor capacity';
comment on column ADM.AGENT.SECURITY_LEVEL is
    '1=HTTP; 4=HTTPS';
comment on column ADM.AGENT.PLUGIN_TIME is
    'Date and time of the last agent plug-in or update';
comment on column ADM.AGENT.LAST_SYNC_TIME is
    'Date and time when offline usage data was last sent';
comment on column ADM.AGENT.SCAN_TIME is
    'Date and time of the last available software scan';
comment on column ADM.AGENT.ACTIVE is
    'If true, the agent is active';
comment on column ADM.AGENT.SERVER_ID is
    'External key to SERVER table';
comment on column ADM.AGENT.NODE_ID is
    'External key to NODE table';
comment on column ADM.AGENT.DIVISION_ID is
    'External key to DIVISION table';
comment on column ADM.AGENT.CUSTOMER_ID is
    'External key to CUSTOMER table.';

-------------------------------------------------------------------------------

comment on table  ADM.AGENT_EVENT is
    'Stores details of events at agents.';
comment on column ADM.AGENT_EVENT.AGENT_ID is
    'External key to AGENT table';
comment on column ADM.AGENT_EVENT.EVENT_ID is
    'The ID of the event. The permitted values are: 1=inventory';
comment on column ADM.AGENT_EVENT.TIME is
    'Time when the event occurred';

-------------------------------------------------------------------------------

comment on table  ADM.AGENT_H is
    'History of AGENT table.';

-------------------------------------------------------------------------------

comment on table  ADM.AGENT_INV is
    'Provides historical software inventory of each agent.';
comment on column ADM.AGENT_INV.AGENT_ID is
    'External key to AGENT table';
comment on column ADM.AGENT_INV.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.AGENT_INV.START_TIME is
    'Date and time of the scan that detected the software';
comment on column ADM.AGENT_INV.END_TIME is
    'Date and time of the first scan after the software was uninstalled or upgraded';

-------------------------------------------------------------------------------

comment on table  ADM.AGENT_INV_LIC is
    'Provides historical license inventory of each agent.';
comment on column ADM.AGENT_INV_LIC.AGENT_INV_ID is
    'External key to AGENT_INV table';
comment on column ADM.AGENT_INV_LIC.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.AGENT_INV_LIC.QUANTITY is
    'The license quantity in use at the agent';
comment on column ADM.AGENT_INV_LIC.START_TIME is
    'Date and time that the license was assigned';
comment on column ADM.AGENT_INV_LIC.END_TIME is
    'Date and time that the license assignement was finished';

-------------------------------------------------------------------------------

comment on table  ADM.AGENT_SYNC_CUST is
    'Stores details by organization of the synchronization ratio at the date of each aggregation.';
comment on column ADM.AGENT_SYNC_CUST.CUSTOMER_ID is
    'External key to CUSTOMER table';
comment on column ADM.AGENT_SYNC_CUST.SYNC_DATE is
    'Date of the aggregation';
comment on column ADM.AGENT_SYNC_CUST.SYNC_RATIO is
    'Proportion of all computers for which updated data is available at the date of the aggregation';

-------------------------------------------------------------------------------

comment on table  ADM.AGENT_SYNC_DIV is
    'Stores details by division of the synchronization ratio at the date of each aggregation.';
comment on column ADM.AGENT_SYNC_DIV.DIVISION_ID is
    'External key to DIVISION table';
comment on column ADM.AGENT_SYNC_DIV.SYNC_DATE is
    'Date of the aggregation';
comment on column ADM.AGENT_SYNC_DIV.SYNC_RATIO is
    'Proportion of all computers for which updated data is available at the date of the aggregation';

-------------------------------------------------------------------------------

comment on table  ADM.CONTRACT is
    'Stores details of contracts.';
comment on column ADM.CONTRACT.CONTRACT_NUM is
    'Contract number';
comment on column ADM.CONTRACT.TYPE is
    'Contract type: warranty=1; service=2; lease=3; loan=4; purchase=5; maintenance=6';
comment on column ADM.CONTRACT.STATUS is
    'Contract status: active=1; closed=2; renewed=3; past due date=4; pending=5';
comment on column ADM.CONTRACT.SUPPLY_VENDOR is
    'The name of the vendor that supplied the product';
comment on column ADM.CONTRACT.PURCHASE_VENDOR is
    'The name of the vendor from which the software was purchased';
comment on column ADM.CONTRACT.OWNER is
    'Owner of the contract';
comment on column ADM.CONTRACT.START_DATE is
    'Start date of the contract';
comment on column ADM.CONTRACT.END_DATE is
    'End date of the contract';
comment on column ADM.CONTRACT.COST is
    'Contract cost';
comment on column ADM.CONTRACT.COST_CURR is
    'ISO currency code of the currency in the COST column (for example: EUR, USD)';
comment on column ADM.CONTRACT.TERMS is
    'Contract terms; free format text';
comment on column ADM.CONTRACT.NOTES is
    'Contract notes; free format text';
comment on column ADM.CONTRACT.MODIFIED_BY is
    'The logon name of the administrator that performed the last update';
comment on column ADM.CONTRACT.EXT_ID is
    'Unique identifier for importing or exporting';
comment on column ADM.CONTRACT.CUSTOMER_ID is
    'External key to CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.CONTROL is
    'Stores configuration information in key-value format.';
comment on column ADM.CONTROL.NAME is
    'The name of a parameter';
comment on column ADM.CONTROL.VALUE is
    'Value assigned to the parameter';

-------------------------------------------------------------------------------

comment on table  ADM.COUNTRY is
    'Stores country information.';
comment on column ADM.COUNTRY.NAME is
    'Name of the country';
comment on column ADM.COUNTRY.ISO_CODE2 is
    'ISO-2 standard country code';
comment on column ADM.COUNTRY.ISO_CODE3 is
    'ISO-3 standard country code';
comment on column ADM.COUNTRY.ISO_CODE4 is
    'ISO-4 standard country code (numeric)';
comment on column ADM.COUNTRY.CURRENCY_NAME is
    'Name of the currency used in the the country';
comment on column ADM.COUNTRY.CURRENCY_CODE is
    'ISO code of the currency';

-------------------------------------------------------------------------------

comment on table  ADM.CUST_OPT_FIELD is
    'Maps the CUSTOMER table to the OPT_FIELD_DEF table (many-to-many). It provides the list of available custom fields for each organization.';
comment on column ADM.CUST_OPT_FIELD.OPT_FIELD_ID is
    'External key to OPT_FIELD_DEF table';
comment on column ADM.CUST_OPT_FIELD.CUSTOMER_ID is
    'External key to CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.CUSTOMER is
    'Stores information about each organization.';
comment on column ADM.CUSTOMER.NAME is
    'Organization name';
comment on column ADM.CUSTOMER.ACCOUNT_ID is
    'Organization account unique ID';
comment on column ADM.CUSTOMER.COUNTRY_CODE is
    'External key to COUNTRY table';
comment on column ADM.CUSTOMER.DESCRIPTION is
    'Free format text';
comment on column ADM.CUSTOMER.CHECK_PERIOD is
    'Not used';
comment on column ADM.CUSTOMER.REQUEST_SCOPE is
    'Not used';
comment on column ADM.CUSTOMER.SECURITY_LEVEL is
    '1=HTTP; 4=HTTPS';

-------------------------------------------------------------------------------

comment on table  ADM.DIVISION is
    'Stores details of divisions that represent the organization primary structural level.';
comment on column ADM.DIVISION.NAME is
    'Division name';
comment on column ADM.DIVISION.INV_START_DATE is
    'The start date for the inventory scan schedule';
comment on column ADM.DIVISION.INV_RATE_TYPE is
    'Inventory rate type (0=once; 1=daily; 2=weekly; 3=monthly)';
comment on column ADM.DIVISION.INV_RATE_VALUE is
    'The number of days, weeks, or months between inventory scans';
comment on column ADM.DIVISION.DESCRIPTION is
    'Free format text';
comment on column ADM.DIVISION.SECURITY_LEVEL is
    '0=inherit from organization, 1=HTTP; 4=HTTPS';
comment on column ADM.DIVISION.EXT_ID is
    'Unique identifier for importing or exporting';
comment on column ADM.DIVISION.CUSTOMER_ID is
    'External key to CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.DIVISION_H is
    'History of DIVISION table.';

-------------------------------------------------------------------------------

comment on table  ADM.ENDUSER is
    'Stores details of users of the applications that are monitored by Tivoli License Manager.';
comment on column ADM.ENDUSER.LOGON_NAME is
    'User ID';
comment on column ADM.ENDUSER.FIRST_NAME is
    'First name of the user';
comment on column ADM.ENDUSER.MIDDLE_NAME is
    'Middle name or names of the user';
comment on column ADM.ENDUSER.LAST_NAME is
    'Surname of the user';
comment on column ADM.ENDUSER.EMPLOYEE_NO is
    'Employee number';
comment on column ADM.ENDUSER.EMAIL_ADDRESS is
    'E-mail address';
comment on column ADM.ENDUSER.LOCATION is
    'Location';
comment on column ADM.ENDUSER.PHONE is
    'Telephone number';
comment on column ADM.ENDUSER.FAX is
    'Fax number';
comment on column ADM.ENDUSER.EXT_ID is
    'Unique identifier for importing or exporting';
comment on column ADM.ENDUSER.CUSTOMER_ID is
    'External key to CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.ENTITLEMENT is
    'Details the usage rules for product licenses for which an organization has set up an entitlement.';
comment on column ADM.ENTITLEMENT.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.ENTITLEMENT.CUSTOMER_ID is
    'External key to CUSTOMER table';
comment on column ADM.ENTITLEMENT.ACTIVE is
    'Indicates whether or not usage tracking is enabled for the component';
comment on column ADM.ENTITLEMENT.LICENSE_CONTROL is
    'Indicates whether or not the server must deny a request when there is no valid license settings are used';
comment on column ADM.ENTITLEMENT.NEED_RESPONSE is
    'Indicates whether or not a response from the server is needed to run the component.';
comment on column ADM.ENTITLEMENT.RUN_OFFLINE is
    'Indicates whether the component can run when the agent is disconnected from the network.';

-------------------------------------------------------------------------------

comment on table  ADM.INV_H_COMP is
    'Stores inventory scan data aggregated by component.';
comment on column ADM.INV_H_COMP.CUSTOMER_ID is
    'External key to CUSTOMER table';
comment on column ADM.INV_H_COMP.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.INV_H_COMP.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.INV_H_COMP.HWM is
    'Installation quantity at the end of the day';
comment on column ADM.INV_H_COMP.UNLICENSED_HWM is
    'Unlicensed installation quantity at the end of the day';
comment on column ADM.INV_H_COMP.RIF_HWM is
    'Installation quantity to be used for unlicensed ratio';

-------------------------------------------------------------------------------

comment on table  ADM.INV_H_LIC is
    'Stores inventory scan data aggregated by license.';
comment on column ADM.INV_H_LIC.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.INV_H_LIC.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.INV_H_LIC.HWM is
    'Installation quantity at the end of the day';

-------------------------------------------------------------------------------

comment on table  ADM.INV_H_LIC_COMP is
    'Stores inventory scan data aggregated by license and component.';
comment on column ADM.INV_H_LIC_COMP.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.INV_H_LIC_COMP.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.INV_H_LIC_COMP.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.INV_H_LIC_COMP.HWM is
    'Installation quantity at the end of the day';

-------------------------------------------------------------------------------

comment on table  ADM.INV_H_PLIC is
    'Stores inventory scan data aggregated by procured license.';
comment on column ADM.INV_H_PLIC.PLICENSE_ID is
    'External key to PLICENSE table';
comment on column ADM.INV_H_PLIC.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.INV_H_PLIC.HWM is
    'Installation quantity at the end of the day';

-------------------------------------------------------------------------------

comment on table  ADM.INV_H_PLIC_COMP is
    'Stores inventory scan data aggregated by procured license and component.';
comment on column ADM.INV_H_PLIC_COMP.PLICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.INV_H_PLIC_COMP.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.INV_H_PLIC_COMP.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.INV_H_PLIC_COMP.HWM is
    'Installation quantity at the end of the day';

-------------------------------------------------------------------------------

comment on table  ADM.LIC_TARGET_HREL is
    'History of LIC_TARGET_REL table.';

-------------------------------------------------------------------------------

comment on table  ADM.LIC_TARGET_REL is
    'Maps license distributions to an organization or to one or more targets (divisions, nodes or agents).';
comment on column ADM.LIC_TARGET_REL.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.LIC_TARGET_REL.TARGET_ID is
    'External key to NODE, AGENT, DIVISION or CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.LIC_USER_HREL is
    'History of LIC_USER_REL table.';

-------------------------------------------------------------------------------

comment on table  ADM.LIC_USER_REL is
    'Maps the relationships between licenses and end-users (many-to-many).';
comment on column ADM.LIC_USER_REL.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.LIC_USER_REL.ENDUSER_ID is
    'External key to ENDUSER table';

-------------------------------------------------------------------------------

comment on table  ADM.LICENSE is
    'Stores information about license pools.';
comment on column ADM.LICENSE.REF_CODE is
    'Licence reference code (unique)';
comment on column ADM.LICENSE.QUANTITY is
    'Quantity of licenses in the pool';
comment on column ADM.LICENSE.TARGET_TYPE is
    'Indicates the type of enrollment:1=organization, 2=divisions, 3=node, 4=agent';
comment on column ADM.LICENSE.ALL_TARGETS is
    '0=specified targets, 1=all targets';
comment on column ADM.LICENSE.ALL_USERS is
    '0=specified users, 1=all users';
comment on column ADM.LICENSE.PLICENSE_ID is
    'External key to PLICENSE table';
comment on column ADM.LICENSE.EXT_ID is
    'Unique identifier for importing or exporting';
comment on column ADM.LICENSE.CUSTOMER_ID is
    'External key to CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.LICENSE_DISTRIBUTION is
    'Stores license pools quantity distributions to runtime servers';
comment on column ADM.LICENSE_DISTRIBUTION.SERVER_ID is
    'External key to SERVER table';
comment on column ADM.LICENSE_DISTRIBUTION.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.LICENSE_DISTRIBUTION.QUANTITY is
    'Distributed quantity';

-------------------------------------------------------------------------------

comment on table  ADM.LICENSE_H is
    'History of LICENSE table.';

-------------------------------------------------------------------------------

comment on table  ADM.NODE is
    'Stores details of systems on which agents are installed.';
comment on column ADM.NODE.TAG is
    'Computer label (inserted during agent deployment)';
comment on column ADM.NODE.PLATFORM is
    'Hardware platform (for example: Intel, Alpha)';
comment on column ADM.NODE.NAME is
    'Unique node name';
comment on column ADM.NODE.HASH is
    'Hash of the node name';
comment on column ADM.NODE.CAPACITY is
    'Node processors capacity';
comment on column ADM.NODE.OOCOD is
    'On Off Capacity on Demand flag';
comment on column ADM.NODE.LOCATION is
    'Free form text';
comment on column ADM.NODE.DESCRIPTION is
    'Free form text';
comment on column ADM.NODE.EXT_ID is
    'Unique identifier for importing or exporting';
comment on column ADM.NODE.CUSTOMER_ID is
    'External key to CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.NODE_H is
    'History of NODE table.';

-------------------------------------------------------------------------------

comment on table  ADM.OID is
    'Stores the most recent (highest) system-generated number for various tables throughout the database.';
comment on column ADM.OID.LAST_ID is
    'Last assigned ID';
comment on column ADM.OID.TABLE_NAME is
    'The name of the table';
comment on column ADM.OID.BLOCK_SIZE is
    'The block of oids used to increase the last_id value';

-------------------------------------------------------------------------------

comment on table  ADM.OPT_FIELD is
    'Stores the values of optional fields.';
comment on column ADM.OPT_FIELD.OPT_FIELD_ID is
    'External key to OPT_FIELD_DEF table';
comment on column ADM.OPT_FIELD.TABLE_RECORD_ID is
    'Record ID of the target table';
comment on column ADM.OPT_FIELD.VALUE is
    'Value of the optional field';

-------------------------------------------------------------------------------

comment on table  ADM.OPT_FIELD_DEF is
    'Defines optional fields. Each line defines one optional field for one table.';
comment on column ADM.OPT_FIELD_DEF.TABLE_NAME is
    'Name of the table';
comment on column ADM.OPT_FIELD_DEF.NAME is
    'Name of the optional field';
comment on column ADM.OPT_FIELD_DEF.TYPE is
    'Type of field: D=date;I=integer; N=number; S=string';

-------------------------------------------------------------------------------

comment on table  ADM.PLIC_COMP_HREL is
    'History of PLIC_COMP_REL table.';

-------------------------------------------------------------------------------

comment on table  ADM.PLIC_COMP_REL is
    'Maps the relationships between procured licenses and components (many-to-many).';
comment on column ADM.PLIC_COMP_REL.PLICENSE_ID is
    'External key to PLICENSE table';
comment on column ADM.PLIC_COMP_REL.COMPONENT_ID is
    'External key to COMPONENT table';

-------------------------------------------------------------------------------

comment on table  ADM.PLICENSE is
    'Stores details of procured software licenses.';
comment on column ADM.PLICENSE.REF_CODE is
    'Procured licence reference code (unique)';
comment on column ADM.PLICENSE.TREE_LEVEL is
    'Component hierarchy level: 1=product, 2=version, 3=release';
comment on column ADM.PLICENSE.SOFTWARE_NAME is
    'Software product name';
comment on column ADM.PLICENSE.OWNER is
    'Owner of the license';
comment on column ADM.PLICENSE.LICENSE_TYPE is
    'Type of agreement: 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 101';
comment on column ADM.PLICENSE.QUANTITY is
    'The quantity of licenses procured (relates to CAPACITY_TYPE)';
comment on column ADM.PLICENSE.CAPACITY_TYPE is
    '0=users, 1=memory, 2=processors, 4=disks';
comment on column ADM.PLICENSE.PURCHASE_TYPE is
    'Type of purchase: 0, 1, 2, 3, 4';
comment on column ADM.PLICENSE.COST is
    'Cost of the license';
comment on column ADM.PLICENSE.COST_CURR is
    'ISO currency code of the currency in the COST column (for example: EUR, USD)';
comment on column ADM.PLICENSE.DELIVERY_DATE is
    'Procured license delivery date';
comment on column ADM.PLICENSE.START_DATE is
    'Start validity date for the procured license';
comment on column ADM.PLICENSE.EXPIRATION_DATE is
    'Maximum validity date for the procured license';
comment on column ADM.PLICENSE.CONTRACT_REF is
    'Contract reference; points to CONTRACT.CONTRACT_NUM';
comment on column ADM.PLICENSE.ORDER_REF is
    'Order reference';
comment on column ADM.PLICENSE.LICENSE_KEY is
    'License key (if appropriate)';
comment on column ADM.PLICENSE.TC is
    'Complete text of the license agreement';
comment on column ADM.PLICENSE.NOTES is
    'License restrictions and additional comments';
comment on column ADM.PLICENSE.HARD_STOP is
    'If true, QUANTITY is an absolute maximum that cannot be exceeded';
comment on column ADM.PLICENSE.MULTI_INSTANCE is
    'Indicates how multiple instances of the same product should be treated: 0=disabled, 1=same user, 2=same group, 3=same node';
comment on column ADM.PLICENSE.THRESHOLD is
    'Usage threshold for warnings';
comment on column ADM.PLICENSE.VERIFIED is
    'License distribution verification flag';
comment on column ADM.PLICENSE.EXT_ID is
    'Unique identifier for importing or exporting';
comment on column ADM.PLICENSE.CUSTOMER_ID is
    'External key to CUSTOMER table';
comment on column ADM.PLICENSE.MODIFIED_BY is
    'The logon name of the administrator that performed the last update';

-------------------------------------------------------------------------------

comment on table  ADM.PLICENSE_H is
    'History of PLICENSE table.';

-------------------------------------------------------------------------------

comment on table  ADM.PROFILE is
    'Describe administrator profiles.';
comment on column ADM.PROFILE.NAME is
    'Profile name';
comment on column ADM.PROFILE.DESCRIPTION is
    'Free format text';

-------------------------------------------------------------------------------

comment on table  ADM.PROFILE_ACTION is
    'Actions not allowed for administrator profiles.';
comment on column ADM.PROFILE_ACTION.PROFILE_ID is
    'External key to PROFILE table';
comment on column ADM.PROFILE_ACTION.ACTION_KEY is
    'Inhibited action';
comment on column ADM.PROFILE_ACTION.ACTION_VALUE is
    'Free format text';

-------------------------------------------------------------------------------

comment on table  ADM.SERVER is
    'Stores informations about the Tivoli License Manager runtime servers.';
comment on column ADM.SERVER.NAME is
    'Name of the runtime server';
comment on column ADM.SERVER.ADDRESS is
    'IP address';
comment on column ADM.SERVER.PASSWORD is
    'Encrypted password to validate communication requests';
comment on column ADM.SERVER.VERSION is
    'Runtime server version';
comment on column ADM.SERVER.PORT_NUMBER is
    'Communication port';
comment on column ADM.SERVER.SSL_PORT_NUMBER is
    'Communication port for SSL';
comment on column ADM.SERVER.SSL_ENABLED is
    'Indicates if SSL is enabled between runtime server and administration server';
comment on column ADM.SERVER.FORCE_SERVICE is
    'Force entire refresh for incremental services';
comment on column ADM.SERVER.DOWNLOAD_PERIOD is
    'Not used';
comment on column ADM.SERVER.UPLOAD_PERIOD is
    'Not used';
comment on column ADM.SERVER.UPDATE_PERIOD is
    'Not used';
comment on column ADM.SERVER.WARNING_TIME is
    'Date and time of last the inactive server mail notification';
comment on column ADM.SERVER.LOCATION is
    'Location of the runtime server';
comment on column ADM.SERVER.OUTAGE_STATUS is
    'Status of the planned outages: 0=not planned; 1=planned; 2=ready; 3=returning';
comment on column ADM.SERVER.BACKUP_SERVER_ID is
    'ID of the backup server';
comment on column ADM.SERVER.CUSTOMER_ID is
    'External key to the CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.SERVER_H is
    'History of SERVER table.';

-------------------------------------------------------------------------------

comment on table  ADM.SERVICE is
    'Provides a history of the service requests made.';
comment on column ADM.SERVICE.SERVICE_ID is
    'Service ID: 1=update agent inventory, 2=update agent info, 3=download topology';
comment on column ADM.SERVICE.SERVER_ID is
    'ID of the requesting server';
comment on column ADM.SERVICE.INSERTED is
    'Date and time when the row was inserted';
comment on column ADM.SERVICE.FORCE_CHECK_TIME is
    'Internal use';
comment on column ADM.SERVICE.DESCRIPTION is
    'Description of the service';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_COMP is
    'Stores product usage information.';
comment on column ADM.USAGE_COMP.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.USAGE_COMP.AGENT_ID is
    'External key to AGENT table';
comment on column ADM.USAGE_COMP.DIVISION_ID is
    'External key to DIVISION table';
comment on column ADM.USAGE_COMP.CUSTOMER_ID is
    'External key to CUSTOMER table';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_COMP_USER is
    'Stores product usage information (users data).';
comment on column ADM.USAGE_COMP_USER.USAGE_COMP_ID is
    'External key to the USAGE_COMP table';
comment on column ADM.USAGE_COMP_USER.USER is
    'Logon name of the user who launched the application';
comment on column ADM.USAGE_COMP_USER.GROUP is
    'Group name of the user who launched the application';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_H_COMP is
    'Stores usage data aggregated by component.';
comment on column ADM.USAGE_H_COMP.CUSTOMER_ID is
    'External key to CUSTOMER table';
comment on column ADM.USAGE_H_COMP.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.USAGE_H_COMP.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.USAGE_H_COMP.HWM is
    'High water mark in the time frame';
comment on column ADM.USAGE_H_COMP.HWM_TIME is
    'Time of the high water mark';
comment on column ADM.USAGE_H_COMP.AWM is
    'Average usage in the time frame';
comment on column ADM.USAGE_H_COMP.UNLICENSED_HWM is
    'Unlicensed high water mark in the time frame';
comment on column ADM.USAGE_H_COMP.RIF_HWM is
    'High water mark to be used for unlicensed ratio';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_H_DIV is
    'Stores usage data aggregated by component and division.';
comment on column ADM.USAGE_H_DIV.DIVISION_ID is
    'External key to DIVISION table';
comment on column ADM.USAGE_H_DIV.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.USAGE_H_DIV.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.USAGE_H_DIV.HWM is
    'High water mark in the time frame';
comment on column ADM.USAGE_H_DIV.HWM_TIME is
    'Time of the high water mark';
comment on column ADM.USAGE_H_DIV.AWM is
    'Average usage in the time frame';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_H_LIC is
    'Stores usage data aggregated by license.';
comment on column ADM.USAGE_H_LIC.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.USAGE_H_LIC.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.USAGE_H_LIC.HWM is
    'High water mark in the time frame';
comment on column ADM.USAGE_H_LIC.HWM_TIME is
    'Time of the high water mark';
comment on column ADM.USAGE_H_LIC.AWM is
    'Average usage in the time frame';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_H_LIC_COMP is
    'Stores usage data aggregated by license and component.';
comment on column ADM.USAGE_H_LIC_COMP.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.USAGE_H_LIC_COMP.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.USAGE_H_LIC_COMP.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.USAGE_H_LIC_COMP.HWM is
    'High water mark in the time frame';
comment on column ADM.USAGE_H_LIC_COMP.HWM_TIME is
    'Time of the high water mark';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_H_OOCOD is
    'Stores usage data related to application running on nodes supporting IPLA pricing.';
comment on column ADM.USAGE_H_OOCOD.NODE_ID is
    'External key to NODE table';
comment on column ADM.USAGE_H_OOCOD.CAPACITY is
    'Processor capacity of the node';
comment on column ADM.USAGE_H_OOCOD.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.USAGE_H_OOCOD.PLICENSE_ID is
    'External key to PLICENSE table';
comment on column ADM.USAGE_H_OOCOD.DATE_USAGE is
    'Date to which this capacity usage refers';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_H_PLIC is
    'Stores usage data aggregated by procured license.';
comment on column ADM.USAGE_H_PLIC.PLICENSE_ID is
    'External key to PLICENSE table';
comment on column ADM.USAGE_H_PLIC.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.USAGE_H_PLIC.HWM is
    'High water mark in the time frame';
comment on column ADM.USAGE_H_PLIC.HWM_TIME is
    'Time of the high water mark';
comment on column ADM.USAGE_H_PLIC.AWM is
    'Average usage in the time frame';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_H_PLIC_COMP is
    'Stores usage data aggregated by procured license and component.';
comment on column ADM.USAGE_H_PLIC_COMP.PLICENSE_ID is
    'External key to PLICENSE table';
comment on column ADM.USAGE_H_PLIC_COMP.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.USAGE_H_PLIC_COMP.DATE_USAGE is
    'Date to which the aggregation refers';
comment on column ADM.USAGE_H_PLIC_COMP.HWM is
    'High water mark in the time frame';
comment on column ADM.USAGE_H_PLIC_COMP.HWM_TIME is
    'Time of the high water mark';

-------------------------------------------------------------------------------

comment on table  ADM.USAGE_LIC is
    'Stores license usage information.';
comment on column ADM.USAGE_LIC.USAGE_COMP_ID is
    'External key to USAGE_COMP table';
comment on column ADM.USAGE_LIC.LICENSE_ID is
    'External key to LICENSE table';
comment on column ADM.USAGE_LIC.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column ADM.USAGE_LIC.QUANTITY is
    'Requested quantity';
comment on column ADM.USAGE_LIC.POOL_HASH is
    'Hash of the shared pool name';
comment on column ADM.USAGE_LIC.POOL_CAPACITY is
    'Shared pool processor capacity';
comment on column ADM.USAGE_LIC.LPAR_HASH is
    'Hash of the logical partition name';
comment on column ADM.USAGE_LIC.LPAR_CAPACITY is
    'Logical partition processor capacity';
comment on column ADM.USAGE_LIC.NODE_HASH is
    'Hash of the node name';
comment on column ADM.USAGE_LIC.NODE_CAPACITY is
    'Node processor capacity';
comment on column ADM.USAGE_LIC.START_TIME is
    'Date and time when the license was granted';
comment on column ADM.USAGE_LIC.END_TIME is
    'Date and time when the license was released';


-------------------------------------------------------------------------------
-- Catalog comments
-------------------------------------------------------------------------------

comment on table  SWCAT.COMP_HIER is
    'Maps the relationships between products, versions and releases.';
comment on column SWCAT.COMP_HIER.RELEASE_ID is
    'External key to COMPONENT table';
comment on column SWCAT.COMP_HIER.VERSION_ID is
    'External key to COMPONENT table';
comment on column SWCAT.COMP_HIER.PRODUCT_ID is
    'External key to COMPONENT table';

-------------------------------------------------------------------------------

comment on table  SWCAT.COMP_MOD_REL is
    'Maps components to modules (many-to-many).';
comment on column SWCAT.COMP_MOD_REL.COMPONENT_ID is
    'External key to COMPONENT table';
comment on column SWCAT.COMP_MOD_REL.MODULE_ID is
    'External key to MODULE table';

-------------------------------------------------------------------------------

comment on table  SWCAT.COMPONENT is
    'Stores details of software products.';
comment on column SWCAT.COMPONENT.NAME is
    'Software product name';
comment on column SWCAT.COMPONENT.VERSION is
    'Software product version';
comment on column SWCAT.COMPONENT.TREE_LEVEL is
    'Component hierarchy level 1=product, 2=version, 3=release';
comment on column SWCAT.COMPONENT.OS_NAME is
    'Operating system name (must be Windows, Unix, OS/400 or JVM).';
comment on column SWCAT.COMPONENT.LEVEL_ is
    'Relevance of the software product. 1 = licensable commercial product; 2 = licensable commercial product (not high cost); 3 = shareware, demo; 4 = freeware (not relevant); 10 = deleted';
comment on column SWCAT.COMPONENT.IS_IBM is
    'Internal use';
comment on column SWCAT.COMPONENT.DESCRIPTION is
    'Free format text';
comment on column SWCAT.COMPONENT.VENDOR_ID is
    'External key to VENDOR table';
comment on column SWCAT.COMPONENT.COMPONENT_ID is
    'External key to COMPONENT table (used to represent software hierarchies)';
comment on column SWCAT.COMPONENT.EXT_ID is
    'Internal use';

-------------------------------------------------------------------------------

comment on table  SWCAT.CONTROL is
    'Stores configuration information in key-value format.';
comment on column SWCAT.CONTROL.NAME is
    'The name of a parameter';
comment on column SWCAT.CONTROL.VALUE is
    'Value assigned to the parameter';

-------------------------------------------------------------------------------

comment on table  SWCAT.MODULE is
    'Stores information about modules used by agents to detect running application.';
comment on column SWCAT.MODULE.NAME is
    'Name of the module according to TYPE field';
comment on column SWCAT.MODULE.SIZE_ is
    'Size of the module according to TYPE field';
comment on column SWCAT.MODULE.OS_NAME is
    'Operating system name (must be Windows, Unix or OS/400, JVM).';
comment on column SWCAT.MODULE.VALUE is
    'Value of the module according to TYPE';
comment on column SWCAT.MODULE.TYPE is
    'Module type: 0, 10, 100, 101, 102, 103, 104, 150, 151, 152, 200, 300';
comment on column SWCAT.MODULE.SCOPE is
    'Monitoring scope: 0=recognition and monitoring, 1=recognition, 2=monitoring';
comment on column SWCAT.MODULE.ENABLED is
    'Indicates whether the entry in the table is reported by the catalog manager: 0=disabled, 1=enabled';
comment on column SWCAT.MODULE.SWARE_DESC is
    'Software description';
comment on column SWCAT.MODULE.SWARE_VERS is
    'Software version';

-------------------------------------------------------------------------------

comment on table  SWCAT.OID is
    'Stores the most recent (highest) system-generated number for various tables throughout the database.';
comment on column SWCAT.OID.LAST_ID is
    'Last assigned ID';
comment on column SWCAT.OID.TABLE_NAME is
    'The name of the table';
comment on column SWCAT.OID.BLOCK_SIZE is
    'The block of oids used to increase the last_id value';

-------------------------------------------------------------------------------

comment on table  SWCAT.UNKNOWN is
    'Stores details of executable files that are installed on nodes running the Tivoli License Manager agent, but not yet in the software catalog.';
comment on column SWCAT.UNKNOWN.NAME is
    'File name';
comment on column SWCAT.UNKNOWN.SIZE_ is
    'File size';
comment on column SWCAT.UNKNOWN.TYPE is
    'Module type: 0, 10, 200, 300';
comment on column SWCAT.UNKNOWN.CHECKSUM is
    'Not used';
comment on column SWCAT.UNKNOWN.OS_NAME is
    'Operating system name';
comment on column SWCAT.UNKNOWN.PATH is
    'Location of the file';
comment on column SWCAT.UNKNOWN.DESCRIPTION is
    'Free format text';
comment on column SWCAT.UNKNOWN.VERSION is
    'Version of the file';
comment on column SWCAT.UNKNOWN.TEXT1 is
    'Free format text';
comment on column SWCAT.UNKNOWN.TEXT2 is
    'Free format text';
comment on column SWCAT.UNKNOWN.ENABLED is
    'Used by catalog manager: 0=disabled, 1=enabled';

-------------------------------------------------------------------------------

comment on table  SWCAT.VENDOR is
    'Stores information about the software vendors.';
comment on column SWCAT.VENDOR.NAME is
    'Name of the software vendor';


-------------------------------------------------------------------------------
-- New grants to user tlmsrv
-------------------------------------------------------------------------------
grant select on table SYSIBM.SYSDUMMY1 to user TLMSRV;
grant connect on database to user TLMSRV;
grant alterin, createin, dropin on schema ADM to user TLMSRV;

--catalog grants
grant select, insert, update, delete on SWCAT.COMP_MOD_REL to user TLMSRV;
grant select, insert, update, delete on SWCAT.COMPONENT to user TLMSRV;
grant select, insert, update, delete on SWCAT.COMP_HIER to user TLMSRV;
grant select, insert, update, delete on SWCAT.CONTROL to user TLMSRV;
grant select, insert, update, delete on SWCAT.MODULE to user TLMSRV;
grant select, insert, update, delete on SWCAT.OID to user TLMSRV;
grant select, insert, update, delete on SWCAT.UNKNOWN to user TLMSRV;
grant select, insert, update, delete on SWCAT.VENDOR to user TLMSRV;

--all of the other grants
grant select, insert, delete, update on ADM.ADMIN_CUST_REL to user TLMSRV;
grant select, insert, delete, update on ADM.ADMINISTRATOR to user TLMSRV;
grant select, insert, delete, update on ADM.AGENT to user TLMSRV;
grant select, insert, delete, update on ADM.AGENT_EVENT to user TLMSRV;
grant select, insert, delete, update on ADM.AGENT_H to user TLMSRV;
grant select, insert, delete, update on ADM.AGENT_INV to user TLMSRV;
grant select, insert, delete, update on ADM.AGENT_INV_LIC to user TLMSRV;
grant select, insert, delete, update on ADM.AGENT_SYNC_CUST to user TLMSRV;
grant select, insert, delete, update on ADM.AGENT_SYNC_DIV to user TLMSRV;
grant select, insert, delete, update on ADM.CONTRACT to user TLMSRV;
grant select, insert, delete, update on ADM.CONTROL to user TLMSRV;
grant select, insert, delete, update on ADM.COUNTRY to user TLMSRV;
grant select, insert, delete, update on ADM.CUST_OPT_FIELD to user TLMSRV;
grant select, insert, delete, update on ADM.CUSTOMER to user TLMSRV;
grant select, insert, delete, update on ADM.DIVISION to user TLMSRV;
grant select, insert, delete, update on ADM.DIVISION_H to user TLMSRV;
grant select, insert, delete, update on ADM.ENDUSER to user TLMSRV;
grant select, insert, delete, update on ADM.ENTITLEMENT to user TLMSRV;
grant select, insert, delete, update on ADM.INV_H_COMP to user TLMSRV;
grant select, insert, delete, update on ADM.INV_H_LIC to user TLMSRV;
grant select, insert, delete, update on ADM.INV_H_LIC_COMP to user TLMSRV;
grant select, insert, delete, update on ADM.INV_H_PLIC to user TLMSRV;
grant select, insert, delete, update on ADM.INV_H_PLIC_COMP to user TLMSRV;
grant select, insert, delete, update on ADM.LIC_TARGET_HREL to user TLMSRV;
grant select, insert, delete, update on ADM.LIC_TARGET_REL to user TLMSRV;
grant select, insert, delete, update on ADM.LIC_USER_HREL to user TLMSRV;
grant select, insert, delete, update on ADM.LIC_USER_REL to user TLMSRV;
grant select, insert, delete, update on ADM.LICENSE to user TLMSRV;
grant select, insert, delete, update on ADM.LICENSE_DISTRIBUTION to user TLMSRV;
grant select, insert, delete, update on ADM.LICENSE_H to user TLMSRV;
grant select, insert, delete, update on ADM.NODE to user TLMSRV;
grant select, insert, delete, update on ADM.NODE_H to user TLMSRV;
grant select, insert, delete, update on ADM.OID to user TLMSRV;
grant select, insert, delete, update on ADM.OPT_FIELD to user TLMSRV;
grant select, insert, delete, update on ADM.OPT_FIELD_DEF to user TLMSRV;
grant select, insert, delete, update on ADM.PLIC_COMP_HREL to user TLMSRV;
grant select, insert, delete, update on ADM.PLIC_COMP_REL to user TLMSRV;
grant select, insert, delete, update on ADM.PLICENSE to user TLMSRV;
grant select, insert, delete, update on ADM.PLICENSE_H to user TLMSRV;
grant select, insert, delete, update on ADM.PROFILE to user TLMSRV;
grant select, insert, delete, update on ADM.PROFILE_ACTION to user TLMSRV;
grant select, insert, delete, update on ADM.SERVER to user TLMSRV;
grant select, insert, delete, update on ADM.SERVER_H to user TLMSRV;
grant select, insert, delete, update on ADM.SERVICE to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_COMP to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_COMP_USER to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_H_COMP to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_H_DIV to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_H_LIC to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_H_LIC_COMP to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_H_OOCOD to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_H_PLIC to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_H_PLIC_COMP to user TLMSRV;
grant select, insert, delete, update on ADM.USAGE_LIC to user TLMSRV;
