@REM #########################################################################
@REM # Licensed Materials - Property of IBM
@REM # 5724-D33
@REM # IBM Tivoli License Manager
@REM #
@REM # (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
@REM #
@REM # US Government Users Restricted Rights - Use, duplication or
@REM # disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@REM #########################################################################

@echo off
SET TLM_LOG_FILE=migration_111_21.log
SET PATH_BK=%PATH%
SET PATH="%DB2PATH%\java\java12\jdk\bin\java";"%DB2PATH%\java\java12\jdk\jre\bin\java";%PATH%
SET JAVA_CLASSPATH="%DB2PATH%\java\db2java.zip";"%DB2PATH%\java\db2jcc.jar";.
SET TLMA_BACKUP_DIR=.\TLMA.0

:: clean old files and bakup dir
if exist %TLM_LOG_FILE% del %TLM_LOG_FILE%
if exist %TLMA_BACKUP_DIR% rmdir /s /q %TLMA_BACKUP_DIR%

:: check DB2 command line environment
if not defined DB2CLP goto :db2EnvError

echo _______________________________________________________________________________ >> %TLM_LOG_FILE%
echo Running migration 111 21 >> %TLM_LOG_FILE%
echo Current date: %DATE% >> %TLM_LOG_FILE%
echo Current time: %TIME% >> %TLM_LOG_FILE%
echo _______________________________________________________________________________ >> %TLM_LOG_FILE%

::-----------------------------------------------------------------------------
:: Checking for database existence
::-----------------------------------------------------------------------------
echo Checking for database existence >> %TLM_LOG_FILE%
db2 +o -z %TLM_LOG_FILE% connect to tlma
if errorlevel 1 goto :dbNotExisting

::-----------------------------------------------------------------------------
:: Performing preliminary checks on db
::-----------------------------------------------------------------------------
echo Preliminary checks on db running... >> %TLM_LOG_FILE%
db2 -f checks_111_21.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :prChecksFailed
echo Preliminary checks completed successfully >> %TLM_LOG_FILE%

::-----------------------------------------------------------------------------
:: Performing database backup - optional
::-----------------------------------------------------------------------------
echo Attempting database backup >> %TLM_LOG_FILE%
echo Attempting database backup
db2 +o -t  -z %TLM_LOG_FILE% backup db TLMA
if errorlevel 1 goto :bkpFailed
echo Db backup completed successfully >> %TLM_LOG_FILE%
echo Db backup completed successfully

::-----------------------------------------------------------------------------
:: Performing 1.1.1 foreign keys, views and triggers drop
::-----------------------------------------------------------------------------
echo Database migration running... it could take several minutes
echo 1.1.1 foreign keys, views and triggers drop running >> %TLM_LOG_FILE%
echo -- running...
db2 +o -z %TLM_LOG_FILE% connect to TLMA
db2 -f drop_111.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :drop111Failed
echo 1.1.1 foreign keys, views and triggers drop completed successfully >> %TLM_LOG_FILE%

::-----------------------------------------------------------------------------
:: Altering db structure - migrating data
::-----------------------------------------------------------------------------
echo Altering db structure - migrating data >> %TLM_LOG_FILE%
echo -- running...
db2 -v -f migrate_111_21.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 2 goto :migrationFailed
echo Database structure and data migration completed successfully >> %TLM_LOG_FILE%

::-----------------------------------------------------------------------------
:: Country code management and eventual warning
::-----------------------------------------------------------------------------
echo Verifying country code for customers >> %TLM_LOG_FILE%
db2 +o -t -z %TLM_LOG_FILE% update ADM.CUSTOMER set COUNTRY_CODE=null where COUNTRY_CODE is null
if errorlevel 1 goto :noCountryCodeNull
echo One or more country code have been set to null because not matching >> %TLM_LOG_FILE%
echo with existing ones >> %TLM_LOG_FILE%
echo One or more country code have been set to null because not matching
echo with existing ones

:noCountryCodeNull
echo All of the country codes were matched with ISO_CODE3 values >> %TLM_LOG_FILE%

::-----------------------------------------------------------------------------
:: Creating contraints, foreing keys, triggers views
::-----------------------------------------------------------------------------
echo Creating contraints, foreing keys, triggers views >> %TLM_LOG_FILE%
echo -- running...
echo Foreing keys and triggers for SWCAT schema >> %TLM_LOG_FILE%
db2 -f swcat_create_fct.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :fctvFailed
echo SWCAT foreign keys and triggers created successfully >> %TLM_LOG_FILE%

echo Contraints and triggers for SWCAT schema >> %TLM_LOG_FILE%
db2 -f swcat_create_tr.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :fctvFailed
echo SWCAT contraints and triggers created successfully >> %TLM_LOG_FILE%

echo Foreing keys and triggers for ADM schema >> %TLM_LOG_FILE%
db2 -f create_fct.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :fctvFailed
echo ADM foreign keys and triggers created successfully >> %TLM_LOG_FILE%

echo Contraints and triggers for ADM schema >> %TLM_LOG_FILE%
db2 -f create_tr.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :fctvFailed
echo ADM contraints and triggers created successfully >> %TLM_LOG_FILE%

echo Views for ADM schema >> %TLM_LOG_FILE%
db2 -f create_v.sql +o -t -z %TLM_LOG_FILE%
if errorlevel 1 goto :fctvFailed
echo ADM views created successfully >> %TLM_LOG_FILE%

::-----------------------------------------------------------------------------
:: Catalog management - after triggers/contraints creation
::-----------------------------------------------------------------------------
echo Building hierarchy over custom entries >> %TLM_LOG_FILE%
echo -- running...
java -cp %JAVA_CLASSPATH% CatalogHandler >> %TLM_LOG_FILE%
if errorlevel 1 goto :customHierFailed

:hierSuccess
echo Hierarchy over custom entries building completed successfully >> %TLM_LOG_FILE%

goto :success

:db2EnvError
echo DB2 environment not initialized >> %TLM_LOG_FILE%
echo Run this command from a DB2 Command Window >> %TLM_LOG_FILE%
echo DB2 environment not initialized
echo Run this command from a DB2 Command Window
SET PATH=%PATH_BK%
goto :eof

:dbNotExisting
echo The administration server db doesn't exist >> %TLM_LOG_FILE%
echo The administration server db doesn't exist
SET PATH=%PATH_BK%
goto :eof

:prChecksFailed
echo Preliminary checks on to be migrated db failed. >> %TLM_LOG_FILE%
echo Check database version is 1.1.1. >> %TLM_LOG_FILE%
echo Cannot start migration procedure. Database version is not the one expected (1.1.1)
goto :disconnectClean

:bkpFailed
echo Database backup failed. >> %TLM_LOG_FILE%
echo Possible causes could be: >> %TLM_LOG_FILE%
echo buffer size not large enough; >> %TLM_LOG_FILE%
echo disk space over; >> %TLM_LOG_FILE%
echo database still in use (server not stopped? another user connected?); >> %TLM_LOG_FILE%
echo running script without needed autorization (how are you logged on?) >> %TLM_LOG_FILE%
echo Database backup failed
echo Possible causes could be:
echo buffer size not large enough;
echo disk space over;
echo database still in use (server not stopped? another user connected?);
echo running script without needed autorization (how are you logged on?)
goto :disconnectClean

:drop111Failed
echo A failure occurred dropping 1.1.1 foreign keys, views and triggers >> %TLM_LOG_FILE%
goto :failure

:migrationFailed
echo A failure occurred altering db structure and migrating data >> %TLM_LOG_FILE%
goto :failure

:fctvFailed
echo A failure occurred creating foreign keys or triggers or views >> %TLM_LOG_FILE%
goto :failure

:customHierFailed
echo A failure occurred managing catalog hierarchy >> %TLM_LOG_FILE%
echo Check JVM is installed and PATH variable is ok, then look in the migration log >> %TLM_LOG_FILE%
goto :failure

:IBMupdateFailed
echo A failure occurred importing IBM catalog >> %TLM_LOG_FILE%
goto :failure

::-------------------------------------
:failure
echo Migration procedure failed - see log (%TLM_LOG_FILE%) for details
echo Dropping corrupted db >> %TLM_LOG_FILE%
db2 -t +o drop db TLMA >> %TLM_LOG_FILE%
echo Creating database to be restored >> %TLM_LOG_FILE%
db2 -f create_db.sql +o -t -z %TLM_LOG_FILE%
echo Restoring db >> %TLM_LOG_FILE%
db2 restore db TLMA replace existing >> %TLM_LOG_FILE%
goto :disconnectClean

::-----------------------------------------------------------------------------
:: Exit successfully
::-----------------------------------------------------------------------------
:success
echo Administration database has been successfully migrated to 2.1.
echo _______________________________________________________________________________ >> %TLM_LOG_FILE%
echo Administration database has been successfully migrated to 2.1. >> %TLM_LOG_FILE%
echo Finished at date: %DATE% >> %TLM_LOG_FILE%
echo Finished at time: %TIME% >> %TLM_LOG_FILE%
echo _______________________________________________________________________________ >> %TLM_LOG_FILE%

::-------------------------------------
:disconnectClean
if exist usage_comp_111_21.dat del usage_comp_111_21.dat
if exist usage_comp_user_111_21.dat del usage_comp_user_111_21.dat
if exist usage_lic_111_21.dat del usage_lic_111_21.dat
SET PATH=%PATH_BK%
db2 +o disconnect TLMA
